@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,6 +25,12 @@
 #include "preferences.h"
 #include "core.h"
 #include "config.h"
+#include "guiconfig.h"
+
+#ifdef Q_OS_WIN
+/* Disable screensaver by event */
+#include <windows.h>
+#endif
 
 class QWidget;
 class QMenu;
@@ -75,6 +81,8 @@ public slots:
 	virtual void openDirectory();
 	virtual void openDirectory(QString directory);
 
+	virtual void helpFAQ();
+	virtual void helpCLOptions();
     virtual void helpAbout();
 	virtual void helpAboutQt();
 
@@ -90,6 +98,8 @@ public slots:
 	virtual void showPreferencesDialog();
 	virtual void showFilePropertiesDialog();
 
+	virtual void showGotoDialog();
+
 	virtual void exitFullscreen();
 	virtual void toggleFullscreen();
     virtual void toggleFullscreen(bool);
@@ -129,8 +139,10 @@ protected slots:
 	virtual void newMediaLoaded();
 	virtual void updateMediaInfo();
 
+#if AUTODISABLE_ACTIONS
 	virtual void enableActionsOnPlaying();
 	virtual void disableActionsOnStop();
+#endif
 
 	virtual void resizeWindow(int w, int h);
 	virtual void hidePanel();
@@ -138,17 +150,22 @@ protected slots:
 	/* virtual void playlistVisibilityChanged(); */
 
 	virtual void displayGotoTime(int);
+	//! You can call this slot to jump to the specified percentage in the video, while dragging the slider.
+	virtual void goToPosOnDragging(int);
 
+	virtual void showPopupMenu();
 	virtual void showPopupMenu( QPoint p );
 	/*
 	virtual void mouseReleaseEvent( QMouseEvent * e );
 	virtual void mouseDoubleClickEvent( QMouseEvent * e );
 	*/
-	virtual void wheelEvent( QWheelEvent * e ) ;
 
 	virtual void leftClickFunction();
+	virtual void rightClickFunction();
 	virtual void doubleClickFunction();
 	virtual void middleClickFunction();
+	virtual void xbutton1ClickFunction();
+	virtual void xbutton2ClickFunction();
 	virtual void processFunction(QString function);
 
 	virtual void dragEnterEvent( QDragEnterEvent * ) ;
@@ -173,17 +190,31 @@ protected slots:
 	virtual void remoteOpenFiles(QStringList files);
 	virtual void remoteAddFiles(QStringList files);
 
+	//! Called when core can't parse the mplayer version and there's no
+	//! version supplied by the user
+	void askForMplayerVersion(QString);
+
+	void showExitCodeFromMplayer(int exit_code);
+	void showErrorFromMplayer(QProcess::ProcessError);
+
 	// stylesheet
+#if ALLOW_CHANGE_STYLESHEET
 	virtual void loadQss(QString filename);
 	virtual void changeStyleSheet(QString style);
+#endif
 
 #if NEW_RESIZE_CODE
 	void calculateDiff(); //!< Updates diff_size
 #endif
 
+#ifdef Q_OS_WIN
+	/* Disable screensaver by event */
+	void clear_just_stopped();
+#endif
+
 signals:
 	void frameChanged(int);
-	void timeChanged(double, int, QString);
+	void timeChanged(QString time_ready_to_print);
 
 	void cursorNearTop(QPoint);
 	void cursorNearBottom(QPoint);
@@ -197,11 +228,18 @@ signals:
 	void middleClicked();
 	*/
 
+	//! Sent when the user wants to close the main window
+	void quitSolicited();
+
 protected:
 	virtual void retranslateStrings();
 	virtual void changeEvent(QEvent * event);
 	virtual void hideEvent( QHideEvent * );
 	virtual void showEvent( QShowEvent * );
+#ifdef Q_OS_WIN
+	/* Disable screensaver by event */
+	virtual bool winEvent ( MSG * m, long * result );
+#endif
 
 	virtual void aboutToEnterFullscreen();
 	virtual void aboutToExitFullscreen();
@@ -219,12 +257,17 @@ protected:
 	void setDataToFileProperties();
 	void initializeGui();
 	void createActions();
+#if AUTODISABLE_ACTIONS
 	void setActionsEnabled(bool);
+#endif
 	void createMenus();
 	void updateRecents();
 	void configureDiscDevices();
 	/* virtual void closeEvent( QCloseEvent * e ); */
 
+protected:
+	virtual void wheelEvent( QWheelEvent * e ) ;
+
 protected:
 	QWidget * panel;
 
@@ -254,6 +297,7 @@ protected:
 	MyAction * forward2Act;
 	MyAction * forward3Act;
 	MyAction * repeatAct;
+	MyAction * gotoAct;
 
 	// Menu Speed
 	MyAction * normalSpeedAct;
@@ -274,6 +318,10 @@ protected:
 	MyAction * deblockAct;
 	MyAction * deringAct;
 	MyAction * addNoiseAct;
+#if NEW_ASPECT_CODE
+	MyAction * addLetterboxAct;
+#endif
+	MyAction * upscaleAct;
 
 	// Menu Audio
 	MyAction * muteAct;
@@ -299,16 +347,21 @@ protected:
 	MyAction * incSubScaleAct;
 	MyAction * decSubScaleAct;
 	MyAction * useAssAct;
+	MyAction * useClosedCaptionAct;
+	MyAction * useForcedSubsOnlyAct;
 
 	// Menu Options
 	MyAction * showPlaylistAct;
 	MyAction * showPropertiesAct;
 	MyAction * frameCounterAct;
+	MyAction * motionVectorsAct;
 	MyAction * showPreferencesAct;
 	MyAction * showLogMplayerAct;
 	MyAction * showLogSmplayerAct;
 
 	// Menu Help
+	MyAction * showFAQAct;
+	MyAction * showCLOptions; // Command line options
 	MyAction * aboutQtAct;
 	MyAction * aboutThisAct;
 
@@ -338,6 +391,8 @@ protected:
 	MyAction * nextChapterAct;
 	MyAction * prevChapterAct;
 	MyAction * doubleSizeAct;
+	MyAction * resetVideoEqualizerAct;
+	MyAction * showContextMenuAct;
 
 	// Moving and zoom
 	MyAction * moveUpAct;
@@ -391,10 +446,20 @@ protected:
 	MyAction * aspect169Act;
 	MyAction * aspect1610Act;
 	MyAction * aspect235Act;
+#if !NEW_ASPECT_CODE
 	MyAction * aspect43LetterAct;
 	MyAction * aspect169LetterAct;
 	MyAction * aspect43PanscanAct;
 	MyAction * aspect43To169Act;
+#endif
+
+	// Rotate Group
+	MyActionGroup * rotateGroup;
+	MyAction * rotateNoneAct;
+	MyAction * rotateClockwiseFlipAct;
+	MyAction * rotateClockwiseAct;
+	MyAction * rotateCounterclockwiseAct;
+	MyAction * rotateCounterclockwiseFlipAct;
 
 	// Audio Channels Action Group
 	MyActionGroup * channelsGroup;
@@ -409,13 +474,14 @@ protected:
 	MyAction * leftChannelAct;
 	MyAction * rightChannelAct;
 
-	// Audio Track Group
+	// Other groups
 	MyActionGroup * audioTrackGroup;
 	MyActionGroup * subtitleTrackGroup;
 	MyActionGroup * titleGroup;
 	MyActionGroup * angleGroup;
 	MyActionGroup * chapterGroup;
 
+
 	// MENUS
 	QMenu *openMenu;
     QMenu *playMenu;
@@ -444,12 +510,14 @@ protected:
 	QMenu * audiofilter_menu;
 	QMenu * logs_menu;
 	QMenu * panscan_menu;
+	QMenu * rotate_menu;
 
 	QMenu * popup;
 	QMenu * recentfiles_menu;
     
     LogWindow * mplayer_log_window;
     LogWindow * smplayer_log_window;
+	LogWindow * clhelp_window;
 
 	PreferencesDialog *pref_dialog;
 	FilePropertiesDialog *file_dialog;
@@ -468,7 +536,6 @@ protected:
 private:
 	QString default_style;
 
-	int last_second;
 	bool near_top;
 	bool near_bottom;
 
@@ -476,10 +543,17 @@ private:
 	// when exiting from fullscreen mode.
 	QPoint win_pos;
 	QSize win_size;
+	bool was_maximized;
 
 #if NEW_RESIZE_CODE
 	QSize diff_size;	//!< Main window size - panel size
 #endif
+
+#ifdef Q_OS_WIN
+	/* Disable screensaver by event */
+	bool just_stopped;
+#endif
+
 };
     
 #endif
