@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 */
 
 #include "baseguiplus.h"
+#include "config.h"
 #include "myaction.h"
 #include "global.h"
 #include "images.h"
@@ -35,13 +36,24 @@
 #define PLAYLIST_ON_SIDES 1
 #endif
 
+using namespace Global;
 
 BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags )
-	: BaseGui( parent, flags ),
-		mainwindow_visible(true),
-		//infowindow_visible(false),
-		trayicon_playlist_was_visible(false)
+	: BaseGui( parent, flags )
 {
+	// Initialize variables
+	mainwindow_visible = true;
+	//infowindow_visible = false;
+	trayicon_playlist_was_visible = false;
+	widgets_size = 0;
+#if DOCK_PLAYLIST
+	fullscreen_playlist_was_visible = false;
+	fullscreen_playlist_was_floating = false;
+	compact_playlist_was_visible = false;
+	ignore_playlist_events = false;
+#endif
+
+
 	mainwindow_pos = pos();
 
 	tray = new QSystemTrayIcon( Images::icon("logo", 22), this );
@@ -69,6 +81,7 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags )
 	context_menu->addSeparator();
 	context_menu->addAction(openFileAct);
 	context_menu->addMenu(recentfiles_menu);
+	context_menu->addAction(openDirectoryAct);
 	context_menu->addAction(openDVDAct);
 	context_menu->addAction(openURLAct);
 	context_menu->addSeparator();
@@ -88,8 +101,8 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags )
 #if DOCK_PLAYLIST
 	// Playlistdock
 	playlistdock = new PlaylistDock(this);
-	playlistdock->setObjectName("playlist");
-	playlistdock->setFloating(true);
+	playlistdock->setObjectName("playlistdock");
+	playlistdock->setFloating(false); // To avoid that the playlist is visible for a moment
 	playlistdock->setWidget(playlist);
 	playlistdock->setAllowedAreas(Qt::TopDockWidgetArea | 
                                   Qt::BottomDockWidgetArea
@@ -100,6 +113,7 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags )
                                   );
 	addDockWidget(Qt::BottomDockWidgetArea, playlistdock);
 	playlistdock->hide();
+	playlistdock->setFloating(true); // Floating by default
 
 	connect( playlistdock, SIGNAL(closed()), this, SLOT(playlistClosed()) );
 	connect( playlistdock, SIGNAL(docked()), this, SLOT(stretchWindow()) );
@@ -118,10 +132,14 @@ BaseGuiPlus::~BaseGuiPlus() {
 }
 
 bool BaseGuiPlus::startHidden() {
+#ifdef Q_OS_WIN
+	return false;
+#else
 	if ( (!showTrayAct->isChecked()) || (mainwindow_visible) ) 
 		return false;
 	else
 		return true;
+#endif
 }
 
 void BaseGuiPlus::closeEvent( QCloseEvent * e ) {
@@ -188,6 +206,15 @@ void BaseGuiPlus::saveConfig() {
 	set->setValue( "show_tray_icon", showTrayAct->isChecked() );
 	set->setValue( "mainwindow_visible", isVisible() );
 
+	set->setValue( "trayicon_playlist_was_visible", trayicon_playlist_was_visible );
+	set->setValue( "widgets_size", widgets_size );
+#if DOCK_PLAYLIST
+	set->setValue( "fullscreen_playlist_was_visible", fullscreen_playlist_was_visible );
+	set->setValue( "fullscreen_playlist_was_floating", fullscreen_playlist_was_floating );
+	set->setValue( "compact_playlist_was_visible", compact_playlist_was_visible );
+	set->setValue( "ignore_playlist_events", ignore_playlist_events );
+#endif
+
 /*
 #if DOCK_PLAYLIST
 	set->setValue( "playlist_and_toolbars_state", saveState() );
@@ -210,6 +237,15 @@ void BaseGuiPlus::loadConfig() {
 
 	mainwindow_visible = set->value("mainwindow_visible", true).toBool();
 
+	trayicon_playlist_was_visible = set->value( "trayicon_playlist_was_visible", trayicon_playlist_was_visible ).toBool();
+	widgets_size = set->value( "widgets_size", widgets_size ).toInt();
+#if DOCK_PLAYLIST
+	fullscreen_playlist_was_visible = set->value( "fullscreen_playlist_was_visible", fullscreen_playlist_was_visible ).toBool();
+	fullscreen_playlist_was_floating = set->value( "fullscreen_playlist_was_floating", fullscreen_playlist_was_floating ).toBool();
+	compact_playlist_was_visible = set->value( "compact_playlist_was_visible", compact_playlist_was_visible ).toBool();
+	ignore_playlist_events = set->value( "ignore_playlist_events", ignore_playlist_events ).toBool();
+#endif
+
 /*
 #if DOCK_PLAYLIST
 	restoreState( set->value( "playlist_and_toolbars_state" ).toByteArray() );
@@ -237,7 +273,10 @@ void BaseGuiPlus::trayIconActivated(QSystemTrayIcon::ActivationReason reason) {
 }
 
 void BaseGuiPlus::toggleShowAll() {
-	showAll( !isVisible() );
+	// Ignore if tray is not visible
+	if (tray->isVisible()) {
+		showAll( !isVisible() );
+	}
 }
 
 void BaseGuiPlus::showAll(bool b) {
@@ -350,19 +389,30 @@ void BaseGuiPlus::aboutToExitFullscreen() {
 }
 
 void BaseGuiPlus::aboutToEnterCompactMode() {
-	BaseGui::aboutToEnterCompactMode();
-
 #if DOCK_PLAYLIST
 	compact_playlist_was_visible = (playlistdock->isVisible() && 
                                     !playlistdock->isFloating());
 	if (compact_playlist_was_visible)
 		playlistdock->hide();
 #endif
+
+    widgets_size = height() - panel->height();
+    qDebug("BaseGuiPlus::aboutToEnterCompactMode: widgets_size: %d", widgets_size);
+
+	BaseGui::aboutToEnterCompactMode();
+
+	if (pref->resize_method == Preferences::Always) {
+		resize( width(), height() - widgets_size );
+	}
 }
 
 void BaseGuiPlus::aboutToExitCompactMode() {
 	BaseGui::aboutToExitCompactMode();
 
+	if (pref->resize_method == Preferences::Always) {
+		resize( width(), height() + widgets_size );
+	}
+
 #if DOCK_PLAYLIST
 	if (compact_playlist_was_visible)
 		playlistdock->show();
@@ -453,7 +503,17 @@ TimeSliderAction * BaseGuiPlus::createTimeSliderAction(QWidget * parent) {
              core, SLOT(goToPos(int)) );
 	connect( timeslider_action, SIGNAL( draggingPos(int) ), 
              this, SLOT(displayGotoTime(int)) );
+	connect( core, SIGNAL(posChanged(int)), 
+             timeslider_action, SLOT(setPos(int)) );
+#if ENABLE_DELAYED_DRAGGING
+	timeslider_action->setDragDelay( pref->time_slider_drag_delay );
 
+	connect( timeslider_action, SIGNAL( delayedDraggingPos(int) ), 
+             this, SLOT(goToPosOnDragging(int)) );
+#else
+	connect( timeslider_action, SIGNAL( draggingPos(int) ), 
+             this, SLOT(goToPosOnDragging(int)) );
+#endif
 	return timeslider_action;
 }
 
