@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #include "basegui.h"
 #include <QSystemTrayIcon>
 #include <QPoint>
-#include "config.h"
+#include "guiconfig.h"
 
 class QMenu;
 class PlaylistDock;
@@ -96,6 +96,8 @@ protected:
 	//QPoint infowindow_pos;
 	//bool infowindow_visible;
 
+   int widgets_size; // To be able to restore the original size after exiting from compact mode
+
 #if DOCK_PLAYLIST
     PlaylistDock * playlistdock;
 	bool fullscreen_playlist_was_visible;
