@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,10 +36,7 @@
 #include <QToolButton>
 #include <QMenuBar>
 
-#if !NEW_CONTROLWIDGET
-#include <QLCDNumber>
-#endif
-
+using namespace Global;
 
 DefaultGui::DefaultGui( QWidget * parent, Qt::WindowFlags flags )
 	: BaseGuiPlus( parent, flags ),
@@ -48,8 +45,8 @@ DefaultGui::DefaultGui( QWidget * parent, Qt::WindowFlags flags )
 {
 	createStatusBar();
 
-	connect( this, SIGNAL(timeChanged(double, int, QString)),
-             this, SLOT(displayTime(double, int, QString)) );
+	connect( this, SIGNAL(timeChanged(QString)),
+             this, SLOT(displayTime(QString)) );
     connect( this, SIGNAL(frameChanged(int)),
              this, SLOT(displayFrame(int)) );
 
@@ -101,8 +98,19 @@ void DefaultGui::createActions() {
 
 	volumeslider_action = createVolumeSliderAction(this);
 	volumeslider_action->disable();
+
+#if MINI_ARROW_BUTTONS
+	QList<QAction*> rewind_actions;
+	rewind_actions << rewind1Act << rewind2Act << rewind3Act;
+	rewindbutton_action = new SeekingButton(rewind_actions, this);
+
+	QList<QAction*> forward_actions;
+	forward_actions << forward1Act << forward2Act << forward3Act;
+	forwardbutton_action = new SeekingButton(forward_actions, this);
+#endif
 }
 
+#if AUTODISABLE_ACTIONS
 void DefaultGui::enableActionsOnPlaying() {
 	qDebug("DefaultGui::enableActionsOnPlaying");
 	BaseGuiPlus::enableActionsOnPlaying();
@@ -118,6 +126,7 @@ void DefaultGui::disableActionsOnStop() {
 	timeslider_action->disable();
 	volumeslider_action->disable();
 }
+#endif // AUTODISABLE_ACTIONS
 
 void DefaultGui::createMenus() {
 	toolbar_menu = new QMenu(this);
@@ -135,8 +144,6 @@ QMenu * DefaultGui::createPopupMenu() {
 }
 
 void DefaultGui::createMainToolBars() {
-	
-
 	toolbar1 = new QToolBar( this );
 	toolbar1->setObjectName("toolbar1");
 	//toolbar1->setMovable(false);
@@ -237,15 +244,23 @@ void DefaultGui::createControlWidget() {
 
 	controlwidget->addSeparator();
 
+#if MINI_ARROW_BUTTONS
+	controlwidget->addAction( rewindbutton_action );
+#else
 	controlwidget->addAction(rewind3Act);
 	controlwidget->addAction(rewind2Act);
 	controlwidget->addAction(rewind1Act);
+#endif
 
 	controlwidget->addAction(timeslider_action);
 
+#if MINI_ARROW_BUTTONS
+	controlwidget->addAction( forwardbutton_action );
+#else
 	controlwidget->addAction(forward1Act);
 	controlwidget->addAction(forward2Act);
 	controlwidget->addAction(forward3Act);
+#endif
 
 	controlwidget->addSeparator();
 
@@ -281,13 +296,25 @@ void DefaultGui::createFloatingControl() {
 	floating_control->toolbar()->addAction(pauseAct);
 	floating_control->toolbar()->addAction(stopAct);
 	floating_control->toolbar()->addSeparator();
+
+#if MINI_ARROW_BUTTONS
+	floating_control->toolbar()->addAction( rewindbutton_action );
+#else
 	floating_control->toolbar()->addAction(rewind3Act);
 	floating_control->toolbar()->addAction(rewind2Act);
 	floating_control->toolbar()->addAction(rewind1Act);
+#endif
+
 	floating_control->toolbar()->addAction(timeslider_action);
+
+#if MINI_ARROW_BUTTONS
+	floating_control->toolbar()->addAction( forwardbutton_action );
+#else
 	floating_control->toolbar()->addAction(forward1Act);
 	floating_control->toolbar()->addAction(forward2Act);
 	floating_control->toolbar()->addAction(forward3Act);
+#endif
+
 	floating_control->toolbar()->addSeparator();
 	floating_control->toolbar()->addAction(fullscreenAct);
 	floating_control->toolbar()->addAction(muteAct);
@@ -295,6 +322,12 @@ void DefaultGui::createFloatingControl() {
 	floating_control->toolbar()->addSeparator();
 	floating_control->toolbar()->addAction(time_label_action);
 
+#ifdef Q_OS_WIN
+	// To make work the ESC key (exit fullscreen) and Ctrl-X (close) in Windows
+	floating_control->addAction(exitFullscreenAct);
+	floating_control->addAction(exitAct);
+#endif
+
 	floating_control->adjustSize();
 }
 
@@ -351,10 +384,8 @@ void DefaultGui::retranslateStrings() {
 }
 
 
-void DefaultGui::displayTime(double sec, int perc, QString text) {
+void DefaultGui::displayTime(QString text) {
 	time_display->setText( text );
-	timeslider_action->setPos(perc);
-
 	time_label->setText(text);
 }
 
@@ -412,6 +443,7 @@ void DefaultGui::aboutToExitFullscreen() {
 }
 
 void DefaultGui::aboutToEnterCompactMode() {
+
 	BaseGuiPlus::aboutToEnterCompactMode();
 
 	// Save visibility of toolbars
@@ -424,12 +456,6 @@ void DefaultGui::aboutToEnterCompactMode() {
 	controlwidget_mini->hide();
 	toolbar1->hide();
 	toolbar2->hide();
-
-	/*
-	if (pref->resize_method == Preferences::Always) {
-		resizeWindow(core->mset.win_width, core->mset.win_height);
-	}
-	*/
 }
 
 void DefaultGui::aboutToExitCompactMode() {
@@ -506,6 +532,8 @@ void DefaultGui::resizeEvent( QResizeEvent * ) {
 	}
 }
 
+#define TOOLBARS_VERSION 2
+
 void DefaultGui::saveConfig() {
 	qDebug("DefaultGui::saveConfig");
 
@@ -529,7 +557,7 @@ void DefaultGui::saveConfig() {
 		set->setValue( "height", height() );
 	}
 
-	set->setValue( "toolbars_state", saveState() );
+	set->setValue( "toolbars_state", saveState(TOOLBARS_VERSION) );
 
 	set->endGroup();
 }
@@ -555,7 +583,7 @@ void DefaultGui::loadConfig() {
 		int width = set->value( "width", this->width() ).toInt();
 		int height = set->value( "height", this->height() ).toInt();
 
-		if (height < 200) {
+		if ( (height < 200) && (!pref->use_mplayer_window) ) {
 			width = 580;
 			height = 440;
 		}
@@ -564,7 +592,7 @@ void DefaultGui::loadConfig() {
 		resize(width,height);
 	}
 
-	restoreState( set->value( "toolbars_state" ).toByteArray() );
+	restoreState( set->value( "toolbars_state" ).toByteArray(), TOOLBARS_VERSION );
 
 	set->endGroup();
 
