@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #ifndef _DEFAULTGUI_H_
 #define _DEFAULTGUI_H_
 
-#include "config.h"
+#include "guiconfig.h"
 #include "baseguiplus.h"
 #include <QPoint>
 
@@ -34,6 +34,9 @@ class VolumeSliderAction;
 class FloatingWidget;
 class QLabel;
 
+#if MINI_ARROW_BUTTONS
+class SeekingButton;
+#endif
 
 class DefaultGui : public BaseGuiPlus
 {
@@ -71,7 +74,7 @@ protected:
 
 protected slots:
 	virtual void updateWidgets();
-	virtual void displayTime(double sec, int perc, QString text);
+	virtual void displayTime(QString text);
 	virtual void displayFrame(int frame);
 
 	virtual void showFloatingControl(QPoint p);
@@ -79,8 +82,10 @@ protected slots:
 	virtual void hideFloatingControls();
 
 	// Reimplemented:
+#if AUTODISABLE_ACTIONS
 	virtual void enableActionsOnPlaying();
 	virtual void disableActionsOnStop();
+#endif
 
 protected:
 	QLabel * time_display;
@@ -98,6 +103,11 @@ protected:
 	TimeSliderAction * timeslider_action;
 	VolumeSliderAction * volumeslider_action;
 
+#if MINI_ARROW_BUTTONS
+	SeekingButton * rewindbutton_action;
+	SeekingButton * forwardbutton_action;
+#endif
+
 	FloatingWidget * floating_control;
 	QLabel * time_label;
 
