@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -50,14 +50,22 @@ Extensions::Extensions()
            << "asf" << "wmv"
            << "bin" << "iso" << "vob"
            << "mkv" << "nsv" << "ram" << "flv"
-           << "ts" << "rmvb" << "dvr-ms";
+           << "rm" << "swf"
+           << "ts" << "rmvb" << "dvr-ms" << "m2t";
 
-	_audio << "mp3" << "ogg" << "wav" << "wma" <<  "ac3" << "ra" << "ape";
+	_audio << "mp3" << "ogg" << "wav" << "wma" <<  "ac3" << "ra" << "ape" << "flac";
 
 	_subtitles << "srt" << "sub" << "ssa" << "ass" << "idx" << "txt" << "smi"
                << "rt" << "utf" << "aqt";
 
-	_playlist << "m3u" << "m3u8";
+	_playlist << "m3u" << "m3u8" << "pls";
+
+	_multimedia = _video;
+	for (int n = 0; n < _audio.count(); n++) {
+		if (!_multimedia.contains(_audio[n])) _multimedia << _audio[n];
+	}
+
+	_all_playable << _multimedia << _playlist;
 }
 
 Extensions::~Extensions() {
