@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,9 +40,13 @@ public:
 	ExtensionList audio() { return _audio; };
 	ExtensionList playlist() { return _playlist; };
 	ExtensionList subtitles() { return _subtitles; };
+	ExtensionList multimedia() { return _multimedia; };
+	ExtensionList allPlayable() { return _all_playable; };
 
 protected:
 	ExtensionList _video, _audio, _playlist, _subtitles;
+	ExtensionList _multimedia; //!< video and audio
+	ExtensionList _all_playable; //!< video, audio and playlist
 };
 
 #endif
