@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,12 +18,12 @@
 
 #include "infofile.h"
 #include <QFileInfo>
+#include <QCoreApplication>
 #include "helper.h"
-#include "config.h"
 #include "constants.h"
 
-InfoFile::InfoFile( QObject * parent ) : QObject(parent) 
-{
+
+InfoFile::InfoFile() {
 	row = 0;
 }
 
@@ -141,7 +141,6 @@ QString InfoFile::getInfo(MediaData md) {
 	}
 
 	// Subtitles
-#if SUBTITLES_BY_INDEX
 	if (md.subs.numItems() > 0) {
 		s += openPar( tr("Subtitles") );
 		row++;
@@ -164,37 +163,18 @@ QString InfoFile::getInfo(MediaData md) {
 			if (lang.isEmpty()) lang = "<i>&lt;"+tr("empty")+"&gt;</i>";
 			QString name = md.subs.itemAt(n).name();
 			if (name.isEmpty()) name = "<i>&lt;"+tr("empty")+"&gt;</i>";
+			/*
 			s += QString("<td>%1</td><td>%2</td><td>%3</td><td>%4</td><td>%5</td>")
                  .arg(n).arg(t).arg(lang).arg(name)
                  .arg(md.subs.itemAt(n).ID());
+			*/
+            s += "<td>" + QString::number(n) + "</td><td>" + t + 
+                 "</td><td>" + lang + "</td><td>" + name + 
+                 "</td><td>" + QString::number(md.subs.itemAt(n).ID()) + "</td>";
 			s += closeItem();
 		}
 		s += closePar();
 	}
-#else
-	if (md.subtitles.numItems() > 0) {
-		s += openPar( tr("Subtitles") );
-		row++;
-		s += openItem();
-		s += "<td>" + tr("#", "Info for translators: this is a abbreviation for number") + "</td><td>" + 
-              tr("Language") + "</td><td>" + tr("Name") +"</td><td>" +
-              tr("ID", "Info for translators: this is a identification code") + "</td>";
-		s += closeItem();
-		for (int n = 0; n < md.subtitles.numItems(); n++) {
-			row++;
-			s += openItem();
-			QString lang = md.subtitles.itemAt(n).lang();
-			if (lang.isEmpty()) lang = "<i>&lt;"+tr("empty")+"&gt;</i>";
-			QString name = md.subtitles.itemAt(n).name();
-			if (name.isEmpty()) name = "<i>&lt;"+tr("empty")+"&gt;</i>";
-			s += QString("<td>%1</td><td>%2</td><td>%3</td><td>%4</td>")
-                 .arg(n).arg(lang).arg(name)
-                 .arg(md.subtitles.itemAt(n).ID());
-			s += closeItem();
-		}
-		s += closePar();
-	}
-#endif
 
 	return s;
 }
@@ -232,4 +212,8 @@ QString InfoFile::addItem( QString tag, QString value ) {
            closeItem();
 }
 
-#include "moc_infofile.cpp"
+
+inline QString InfoFile::tr( const char * sourceText, const char * comment, int n )  {
+	return QCoreApplication::translate("InfoFile", sourceText, comment, QCoreApplication:: CodecForTr, n );
+}
+
