@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include "helper.h"
 #include "global.h"
 #include "preferences.h"
+#include "mplayerversion.h"
 
 #if USE_QPROCESS
 #include <QProcess>
@@ -31,6 +32,8 @@
 #include "myprocess.h"
 #endif
 
+using namespace Global;
+
 #define NOME 0
 #define VO 1
 #define AO 2
@@ -72,6 +75,7 @@ void InfoReader::getInfo() {
 	vo_list.clear();
 	ao_list.clear();
 	demuxer_list.clear();
+	mplayer_svn = -1;
 
 	run("-identify -vo help -ao help -demuxer help -vc help -ac help");
 
@@ -120,8 +124,14 @@ static QRegExp rx_driver("\\t(.*)\\t(.*)");
 static QRegExp rx_demuxer("^\\s+([A-Z,a-z,0-9]+)\\s+(\\d+)\\s+(\\S.*)");
 static QRegExp rx_codec("^([A-Z,a-z,0-9]+)\\s+([A-Z,a-z,0-9]+)\\s+([A-Z,a-z,0-9]+)\\s+(\\S.*)");
 
-void InfoReader::readLine(QByteArray line) {
-	qDebug("InfoReader::readLine: line: '%s'", line.data());
+void InfoReader::readLine(QByteArray ba) {
+#if COLOR_OUTPUT_SUPPORT
+    QString line = Helper::stripColorsTags(QString::fromLocal8Bit(ba));
+#else
+	QString line = QString::fromLocal8Bit(ba);
+#endif
+
+	qDebug("InfoReader::readLine: line: '%s'", line.toUtf8().data());
 	//qDebug("waiting_for_key: %d", waiting_for_key);
 
 	if (!waiting_for_key) {
@@ -192,6 +202,10 @@ void InfoReader::readLine(QByteArray line) {
 		waiting_for_key = FALSE;
 		qDebug("InfoReader::readLines: found key: vc");
 	}
+
+	if (line.startsWith("MPlayer ")) {
+		mplayer_svn = MplayerVersion::mplayerVersion(line);
+	}
 }
 
 #if USE_QPROCESS
