@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -70,6 +70,10 @@ public:
 	InfoList vcList() { return vc_list; };
 	InfoList acList() { return ac_list; };
 
+	int mplayerVersion() { return mplayer_svn; };
+
+	//! Returns an InfoReader objects. If it didn't exist before, one
+	//! is created and getInfo() is called.
 	static InfoReader * obj();
 
 protected slots:
@@ -93,6 +97,8 @@ protected:
 	InfoList vc_list;
 	InfoList ac_list;
 
+	int mplayer_svn;
+
 private:
 	bool waiting_for_key;
 	int reading_type;
@@ -100,5 +106,4 @@ private:
 	static InfoReader * static_obj;
 };
 
-
 #endif
