@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,8 @@
 #include <QToolBar>
 #include <QStatusBar>
 
+using namespace Global;
+
 MiniGui::MiniGui( QWidget * parent, Qt::WindowFlags flags )
 	: BaseGuiPlus( parent, flags ), 
 		floating_control_width(80),
@@ -35,9 +37,6 @@ MiniGui::MiniGui( QWidget * parent, Qt::WindowFlags flags )
 	createControlWidget();
 	createFloatingControl();
 
-	connect( this, SIGNAL(timeChanged(double, int, QString)),
-             this, SLOT(displayTime(double, int, QString)) );
-
 	connect( this, SIGNAL(cursorNearBottom(QPoint)),
              this, SLOT(showFloatingControl(QPoint)) );
 
@@ -115,6 +114,7 @@ void MiniGui::retranslateStrings() {
 	controlwidget->setWindowTitle( tr("Control bar") );
 }
 
+#if AUTODISABLE_ACTIONS
 void MiniGui::enableActionsOnPlaying() {
 	BaseGuiPlus::enableActionsOnPlaying();
 
@@ -132,10 +132,7 @@ void MiniGui::disableActionsOnStop() {
 	volumeslider_action->disable();
 #endif
 }
-
-void MiniGui::displayTime(double sec, int perc, QString text) {
-	timeslider_action->setPos(perc);
-}
+#endif // AUTODISABLE_ACTIONS
 
 void MiniGui::aboutToEnterFullscreen() {
 	BaseGuiPlus::aboutToEnterFullscreen();
@@ -180,11 +177,13 @@ void MiniGui::hideFloatingControl() {
 	floating_control->hide();
 }
 
+#define TOOLBARS_VERSION 2
+
 void MiniGui::saveConfig() {
 	QSettings * set = settings;
 
 	set->beginGroup( "mini_gui");
-	set->setValue( "toolbars_state", saveState() );
+	set->setValue( "toolbars_state", saveState(TOOLBARS_VERSION) );
 	set->setValue("floating_control_width", floating_control_width);
 	set->setValue("floating_control_animated", floating_control_animated);
 	set->endGroup();
@@ -194,7 +193,7 @@ void MiniGui::loadConfig() {
 	QSettings * set = settings;
 
 	set->beginGroup( "mini_gui");
-	restoreState( set->value( "toolbars_state" ).toByteArray() );
+	restoreState( set->value( "toolbars_state" ).toByteArray(), TOOLBARS_VERSION );
 	floating_control_width = set->value("floating_control_width", floating_control_width).toInt();
 	floating_control_animated = set->value("floating_control_animated", floating_control_animated).toBool();
 	set->endGroup();
