@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,8 +20,9 @@
 #define _MINI_GUI_H_
 
 #include "baseguiplus.h"
+#include "guiconfig.h"
 
-#define USE_VOLUME_BAR 0
+#define USE_VOLUME_BAR 1
 
 class TimeSliderAction;
 class VolumeSliderAction;
@@ -37,13 +38,14 @@ public:
 	~MiniGui();
 
 protected slots:
-	void displayTime(double sec, int perc, QString text);
 	void showFloatingControl(QPoint p);
 	void hideFloatingControl();
 
 	// Reimplemented:
+#if AUTODISABLE_ACTIONS
 	virtual void enableActionsOnPlaying();
 	virtual void disableActionsOnStop();
+#endif
 
 protected:
 	virtual void retranslateStrings();
