@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -49,11 +49,15 @@
 #include "version.h"
 #include "global.h"
 #include "core.h"
-#include "config.h"
 #include "extensions.h"
+#include "guiconfig.h"
+#include "playlistpreferences.h"
 
 #include <stdlib.h>
 
+#if USE_INFOPROVIDER
+#include "infoprovider.h"
+#endif
 
 #define DRAG_ITEMS 0
 
@@ -61,10 +65,20 @@
 #define COL_NAME 1
 #define COL_TIME 2
 
+using namespace Global;
+
 
 Playlist::Playlist( Core *c, QWidget * parent, Qt::WindowFlags f)
 	: QWidget(parent,f) 
 {
+	save_playlist_in_config = true;
+	recursive_add_directory = false;
+#ifdef Q_OS_WIN
+	automatically_get_info = false;
+#else
+	automatically_get_info = true;
+#endif
+
 	modified = false;
 
 	core = c;
@@ -179,6 +193,9 @@ void Playlist::createActions() {
 	shuffleAct = new MyAction(this, "pl_shuffle", false);
 	shuffleAct->setCheckable(true);
 
+	preferencesAct = new MyAction(this, "pl_preferences", false);
+	connect( preferencesAct, SIGNAL(triggered()), this, SLOT(editPreferences()) );
+
 	// Add actions
 	addCurrentAct = new MyAction(this, "pl_add_current", false);
 	connect( addCurrentAct, SIGNAL(triggered()), this, SLOT(addCurrentFile()) );
@@ -240,6 +257,8 @@ void Playlist::createToolbar() {
 	toolbar->addSeparator();
 	toolbar->addAction(moveUpAct);
 	toolbar->addAction(moveDownAct);
+	toolbar->addSeparator();
+	toolbar->addAction(preferencesAct);
 
 	// Popup menu
 	popup = new QMenu(this);
@@ -279,6 +298,8 @@ void Playlist::retranslateStrings() {
 	repeatAct->change( Images::icon("repeat"), tr("&Repeat") );
 	shuffleAct->change( Images::icon("shuffle"), tr("S&huffle") );
 
+	preferencesAct->change( Images::icon("prefs"), tr("Preferences") );
+
 	// Add actions
 	addCurrentAct->change( tr("Add &current file") );
 	addFilesAct->change( tr("Add &file(s)") );
@@ -496,6 +517,50 @@ void Playlist::load_m3u(QString file) {
 	}
 }
 
+void Playlist::load_pls(QString file) {
+	qDebug("Playlist::load_pls");
+
+	playlist_path = QFileInfo(file).path();
+
+	QSettings set(file, QSettings::IniFormat);
+	set.beginGroup( "playlist");
+
+	if (set.status() == QSettings::NoError) {
+		clear();
+		QString filename;
+		QString name;
+		double duration;
+
+		int num_items = set.value("NumberOfEntries", 0).toInt();
+
+		for (int n=0; n < num_items; n++) {
+			filename = set.value("File"+QString::number(n+1), "").toString();
+			name = set.value("Title"+QString::number(n+1), "").toString();
+			duration = (double) set.value("Length"+QString::number(n+1), 0).toInt();
+
+			QFileInfo fi(filename);
+			if (fi.exists()) {
+				filename = fi.absoluteFilePath();
+			}
+			if (!fi.exists()) {
+				if (QFileInfo( playlist_path + "/" + filename).exists() ) {
+					filename = playlist_path + "/" + filename;
+				}
+			}
+			addItem( filename, name, duration );
+		}
+	}
+
+	set.endGroup();
+
+	list();
+	updateView();
+
+	setModified( false );
+
+	if (set.status() == QSettings::NoError) startPlay();
+}
+
 bool Playlist::save_m3u(QString file) {
 	qDebug("Playlist::save_m3u: '%s'", file.toUtf8().data());
 
@@ -548,6 +613,55 @@ bool Playlist::save_m3u(QString file) {
 	}
 }
 
+
+bool Playlist::save_pls(QString file) {
+	qDebug("Playlist::save_pls: '%s'", file.toUtf8().data());
+
+	QString dir_path = QFileInfo(file).path();
+	if (!dir_path.endsWith("/")) dir_path += "/";
+
+	#ifdef Q_OS_WIN
+	dir_path = Helper::changeSlashes(dir_path);
+	#endif
+
+	qDebug(" * dirPath: '%s'", dir_path.toUtf8().data());
+
+	QSettings set(file, QSettings::IniFormat);
+	set.beginGroup( "playlist");
+	
+	QString filename;
+
+	PlaylistItemList::iterator it;
+	for ( int n=0; n < pl.count(); n++ ) {
+		filename = pl[n].filename();
+		#ifdef Q_OS_WIN
+		filename = Helper::changeSlashes(filename);
+		#endif
+
+		// Try to save the filename as relative instead of absolute
+		if (filename.startsWith( dir_path )) {
+			filename = filename.mid( dir_path.length() );
+		}
+
+		set.setValue("File"+QString::number(n+1), filename);
+		set.setValue("Title"+QString::number(n+1), pl[n].name());
+		set.setValue("Length"+QString::number(n+1), (int) pl[n].duration());
+	}
+
+	set.setValue("NumberOfEntries", pl.count());
+	set.setValue("Version", 2);
+
+	set.endGroup();
+
+	set.sync();
+
+	bool ok = (set.status() == QSettings::NoError);
+	if (ok) setModified( false );
+
+	return ok;
+}
+
+
 void Playlist::load() {
 	if (maybeSave()) {
 		Extensions e;
@@ -558,7 +672,11 @@ void Playlist::load() {
 
 		if (!s.isEmpty()) {
 			latest_dir = QFileInfo(s).absolutePath();
-			load_m3u(s);
+
+			if (QFileInfo(s).suffix().toLower() == "pls")
+				load_pls(s);
+			else
+				load_m3u(s);
 		}
 	}
 }
@@ -588,7 +706,12 @@ bool Playlist::save() {
 			}
 		}
 		latest_dir = QFileInfo(s).absolutePath();
-		return save_m3u(s);
+
+		if (QFileInfo(s).suffix().toLower() == "pls")
+			return save_pls(s);
+		else
+			return save_m3u(s);
+
 	} else {
 		return false;
 	}
@@ -756,24 +879,49 @@ void Playlist::addFiles() {
 	if (files.count()!=0) addFiles(files);  
 }
 
-void Playlist::addFiles(QStringList files) {
+void Playlist::addFiles(QStringList files, AutoGetInfo auto_get_info) {
 	qDebug("Playlist::addFiles");
 
+#if USE_INFOPROVIDER
+	bool get_info = (auto_get_info == GetInfo);
+	if (auto_get_info == UserDefined) {
+		get_info = automatically_get_info;
+	}
+
+	MediaData data;
+	setCursor(Qt::WaitCursor);
+#endif
+
     QStringList::Iterator it = files.begin();
     while( it != files.end() ) {
+#if USE_INFOPROVIDER
+		if ( (get_info) && (QFile::exists((*it))) ) {
+			data = InfoProvider::getInfo( (*it) );
+			addItem( (*it), data.displayName(), data.duration );
+			updateView();
+			qApp->processEvents();
+		} else {
+			addItem( (*it), "", 0 );
+		}
+#else
     	addItem( (*it), "", 0 );
+#endif
+
 		// FIXME: set latest_dir only if the file is a local file,
         // to avoid that dvd:, vcd: and so on will be used.
 		/* latest_dir = QFileInfo((*it)).dirPath(TRUE); */
         ++it;
     }
+#if USE_INFOPROVIDER
+	unsetCursor();
+#endif
 	updateView();
 
 	qDebug( " * latest_dir: '%s'", latest_dir.toUtf8().data() );
 }
 
-void Playlist::addFile(QString file) {
-	addFiles( QStringList() << file );
+void Playlist::addFile(QString file, AutoGetInfo auto_get_info) {
+	addFiles( QStringList() << file, auto_get_info );
 }
 
 void Playlist::addDirectory() {
@@ -787,7 +935,13 @@ void Playlist::addDirectory() {
 	}
 }
 
-void Playlist::addDirectory(QString dir) {
+void Playlist::addOneDirectory(QString dir) {
+	QStringList filelist;
+
+	Extensions e;
+	QRegExp rx_ext(e.multimedia().forRegExp());
+	rx_ext.setCaseSensitivity(Qt::CaseInsensitive);
+
 	QStringList dir_list = QDir(dir).entryList();
 
 	QString filename;
@@ -796,12 +950,29 @@ void Playlist::addDirectory(QString dir) {
 		filename = dir;
 		if (filename.right(1)!="/") filename += "/";
 		filename += (*it);
-		if (!QFileInfo(filename).isDir()) {
-			addItem( filename, "", 0 );
+		QFileInfo fi(filename);
+		if (!fi.isDir()) {
+			if (rx_ext.indexIn(fi.suffix()) > -1) {
+				filelist << filename;
+			}
 		}
 		++it;
 	}
-	updateView();
+	addFiles(filelist);
+}
+
+void Playlist::addDirectory(QString dir) {
+	addOneDirectory(dir);
+
+	if (recursive_add_directory) {
+		QFileInfoList dir_list = QDir(dir).entryInfoList(QStringList() << "*", QDir::AllDirs | QDir::NoDotAndDotDot);
+		for (int n=0; n < dir_list.count(); n++) {
+			if (dir_list[n].isDir()) {
+				qDebug("Playlist::addDirectory: adding directory: %s", dir_list[n].filePath().toUtf8().data());
+				addDirectory(dir_list[n].filePath());
+			}
+		}
+	}
 }
 
 // Remove selected items
@@ -809,11 +980,13 @@ void Playlist::removeSelected() {
 	qDebug("Playlist::removeSelected");
 
 	int first_selected = -1;
+	int number_previous_item = 0;
 
 	for (int n=0; n < listView->rowCount(); n++) {
 		if (listView->isSelected(n, 0)) {
 			qDebug(" row %d selected", n);
 			pl[n].setMarkForDeletion(TRUE);
+			number_previous_item++;
 			if (first_selected == -1) first_selected = n;
 		}
 	}
@@ -828,6 +1001,11 @@ void Playlist::removeSelected() {
 		}
 	}
 
+
+    if (first_selected < current_item) {
+        current_item -= number_previous_item;
+    }
+
 	if (isEmpty()) setModified(false);
 	updateView();
 
@@ -952,6 +1130,20 @@ void Playlist::editItem(int item) {
     } 
 }
 
+void Playlist::editPreferences() {
+	PlaylistPreferences d(this);
+
+	d.setDirectoryRecursion(recursive_add_directory);
+	d.setAutoGetInfo(automatically_get_info);
+	d.setSavePlaylistOnExit(save_playlist_in_config);
+
+	if (d.exec() == QDialog::Accepted) {
+		recursive_add_directory = d.directoryRecursion();
+		automatically_get_info = d.autoGetInfo();
+		save_playlist_in_config = d.savePlaylistOnExit();
+	}
+}
+
 // Drag&drop
 void Playlist::dragEnterEvent( QDragEnterEvent *e ) {
 	qDebug("Playlist::dragEnterEvent");
@@ -1027,6 +1219,11 @@ void Playlist::saveSettings() {
 
 	set->setValue( "repeat", repeatAct->isChecked() );
 	set->setValue( "shuffle", shuffleAct->isChecked() );
+
+	set->setValue( "auto_get_info", automatically_get_info );
+	set->setValue( "recursive_add_directory", recursive_add_directory );
+	set->setValue( "save_playlist_in_config", save_playlist_in_config );
+
 //#if !DOCK_PLAYLIST
 	set->setValue( "window_width", size().width() );
 	set->setValue( "window_height", size().height() );
@@ -1035,19 +1232,21 @@ void Playlist::saveSettings() {
 
 	set->endGroup();
 
-	//Save current list
-	set->beginGroup( "playlist_contents");
+	if (save_playlist_in_config) {
+		//Save current list
+		set->beginGroup( "playlist_contents");
 
-	set->setValue( "count", (int) pl.count() );
-	for ( int n=0; n < pl.count(); n++ ) {
-		set->setValue( QString("item_%1_filename").arg(n), pl[n].filename() );
-		set->setValue( QString("item_%1_duration").arg(n), pl[n].duration() );
-		set->setValue( QString("item_%1_name").arg(n), pl[n].name() );
+		set->setValue( "count", (int) pl.count() );
+		for ( int n=0; n < pl.count(); n++ ) {
+			set->setValue( QString("item_%1_filename").arg(n), pl[n].filename() );
+			set->setValue( QString("item_%1_duration").arg(n), pl[n].duration() );
+			set->setValue( QString("item_%1_name").arg(n), pl[n].name() );
+		}
+		set->setValue( "current_item", current_item );
+		set->setValue( "modified", modified );
+
+		set->endGroup();
 	}
-	set->setValue( "current_item", current_item );
-	set->setValue( "modified", modified );
-
-	set->endGroup();
 }
 
 void Playlist::loadSettings() {
@@ -1060,6 +1259,10 @@ void Playlist::loadSettings() {
 	repeatAct->setChecked( set->value( "repeat", repeatAct->isChecked() ).toBool() );
 	shuffleAct->setChecked( set->value( "shuffle", shuffleAct->isChecked() ).toBool() );
 
+	automatically_get_info = set->value( "auto_get_info", automatically_get_info ).toBool();
+	recursive_add_directory = set->value( "recursive_add_directory", recursive_add_directory ).toBool();
+	save_playlist_in_config = set->value( "save_playlist_in_config", save_playlist_in_config ).toBool();
+
 //#if !DOCK_PLAYLIST
 	QSize s;
 	s.setWidth( set->value( "window_width", size().width() ).toInt() );
@@ -1071,23 +1274,25 @@ void Playlist::loadSettings() {
 
 	set->endGroup();
 
-	//Load latest list
-	set->beginGroup( "playlist_contents");
+	if (save_playlist_in_config) {
+		//Load latest list
+		set->beginGroup( "playlist_contents");
 
-	int count = set->value( "count", 0 ).toInt();
-	QString filename, name;
-	double duration;
-	for ( int n=0; n < count; n++ ) {
-		filename = set->value( QString("item_%1_filename").arg(n), "" ).toString();
-		duration = set->value( QString("item_%1_duration").arg(n), -1 ).toDouble();
-		name = set->value( QString("item_%1_name").arg(n), "" ).toString();
-		addItem( filename, name, duration );
+		int count = set->value( "count", 0 ).toInt();
+		QString filename, name;
+		double duration;
+		for ( int n=0; n < count; n++ ) {
+			filename = set->value( QString("item_%1_filename").arg(n), "" ).toString();
+			duration = set->value( QString("item_%1_duration").arg(n), -1 ).toDouble();
+			name = set->value( QString("item_%1_name").arg(n), "" ).toString();
+			addItem( filename, name, duration );
+		}
+		setCurrentItem( set->value( "current_item", -1 ).toInt() );
+		setModified( set->value( "modified", false ).toBool() );
+		updateView();
+
+		set->endGroup();
 	}
-	setCurrentItem( set->value( "current_item", -1 ).toInt() );
-	setModified( set->value( "modified", false ).toBool() );
-	updateView();
-
-	set->endGroup();
 }
 
 QString Playlist::lastDir() {
