@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -66,6 +66,8 @@ class Playlist : public QWidget
 	Q_OBJECT
 
 public:
+	enum AutoGetInfo { NoGetInfo = 0, GetInfo = 1, UserDefined = 2 };
+
 	Playlist( Core *c, QWidget * parent = 0, Qt::WindowFlags f = Qt::Window );
 	~Playlist();
 
@@ -95,10 +97,17 @@ public slots:
 	virtual void addFiles();
 	virtual void addDirectory();
 
-	virtual void addFile(QString file);
-	virtual void addFiles(QStringList files);
+	virtual void addFile(QString file, AutoGetInfo auto_get_info = UserDefined);
+	virtual void addFiles(QStringList files, AutoGetInfo auto_get_info = UserDefined);
+
+	// Adds a directory, no recursive
+	virtual void addOneDirectory(QString dir);
+
+	// Adds a directory, maybe with recursion (depends on user config)
 	virtual void addDirectory(QString dir);
 
+	void editPreferences();
+
 	virtual bool maybeSave();
     virtual void load();
     virtual bool save();
@@ -106,6 +115,9 @@ public slots:
 	virtual void load_m3u(QString file);
 	virtual bool save_m3u(QString file);
 
+	virtual void load_pls(QString file);
+	virtual bool save_pls(QString file);
+
 	virtual void getMediaInfo();
 
 	void setModified(bool);
@@ -183,6 +195,8 @@ protected:
 	MyAction * nextAct;
 	MyAction * repeatAct;
 	MyAction * shuffleAct;
+	MyAction * preferencesAct;
+
 	MyAction * moveUpAct;
 	MyAction * moveDownAct;
 	MyAction * editAct;
@@ -197,6 +211,11 @@ protected:
 private:
 	bool modified;
 	QTimer * save_timer;
+
+	//Preferences
+	bool recursive_add_directory;
+	bool automatically_get_info;
+	bool save_playlist_in_config;
 };
 
 
