@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "prefadvanced.h"
 #include "images.h"
 #include "preferences.h"
-
+#include "config.h"
 #include <QColorDialog>
 
 PrefAdvanced::PrefAdvanced(QWidget * parent, Qt::WindowFlags f)
@@ -28,6 +28,16 @@ PrefAdvanced::PrefAdvanced(QWidget * parent, Qt::WindowFlags f)
 {
 	setupUi(this);
 
+#ifndef Q_OS_WIN
+	shortnames_check->hide();
+#endif
+
+#if !USE_COLORKEY
+	colorkey_label->hide();
+	colorkey_view->hide();
+	changeButton->hide();
+#endif
+
 	// Monitor aspect
 	monitoraspect_combo->addItem("Auto");
 	monitoraspect_combo->addItem("4:3");
@@ -36,17 +46,21 @@ PrefAdvanced::PrefAdvanced(QWidget * parent, Qt::WindowFlags f)
 	monitoraspect_combo->addItem("16:10");
 
 	// MPlayer language combos.
-    endoffile_combo->addItem( "Exiting... \\(End of file\\)" );
-    endoffile_combo->addItem( "Saliendo... \\(Fin de archivo\\.\\)" );
-    endoffile_combo->addItem( "Beenden... \\(Dateiende erreicht\\)" );
-    endoffile_combo->addItem( "Sortie... \\(Fin du fichier\\)" );
-    endoffile_combo->addItem( "In uscita... \\(Fine del file\\)" );
+    endoffile_combo->addItem( "Exiting... \\(End of file\\)" ); // English
+    endoffile_combo->addItem( "Saliendo... \\(Fin de archivo\\.\\)" ); // Spanish
+    endoffile_combo->addItem( "Beenden... \\(Dateiende erreicht\\)" ); // German
+    endoffile_combo->addItem( "Sortie... \\(Fin du fichier\\)" ); // French
+    endoffile_combo->addItem( "In uscita... \\(Fine del file\\)" ); // Italian
+    endoffile_combo->addItem( QString::fromUtf8("Wychodzę... \\(Koniec pliku\\)") ); // Polish
+    endoffile_combo->addItem( QString::fromUtf8("Выходим... \\(Конец файла\\)") ); // Russian
 
-    novideo_combo->addItem( "Video: no video" );
-	novideo_combo->addItem( QString::fromLatin1("Vdeo: no hay video") );
-    novideo_combo->addItem( "Video: kein Video" );
-    novideo_combo->addItem( QString::fromLatin1("Vido : pas de vido") );
-    novideo_combo->addItem( "Video: nessun video" );
+    novideo_combo->addItem( "Video: no video" ); // English
+    novideo_combo->addItem( QString::fromUtf8("Vídeo: no hay video") ); // Spanish
+    novideo_combo->addItem( "Video: kein Video" ); // German
+    novideo_combo->addItem( QString::fromUtf8("Vidéo : pas de vidéo") ); // French
+    novideo_combo->addItem( "Video: nessun video" ); // Italian
+    novideo_combo->addItem( "Wideo: brak obrazu" ); // Polish
+    novideo_combo->addItem( QString::fromUtf8("Видео: нет видео") ); // Russian
 
 	retranslateStrings();
 }
@@ -82,7 +96,9 @@ void PrefAdvanced::setData(Preferences * pref) {
 	setMplayerAdditionalArguments( pref->mplayer_additional_options );
 	setMplayerAdditionalVideoFilters( pref->mplayer_additional_video_filters );
 	setMplayerAdditionalAudioFilters( pref->mplayer_additional_audio_filters );
+#if USE_COLORKEY
 	setColorKey( pref->color_key );
+#endif
 
 	setLogMplayer( pref->log_mplayer );
 	setLogSmplayer( pref->log_smplayer );
@@ -93,13 +109,17 @@ void PrefAdvanced::setData(Preferences * pref) {
 
 	setEndOfFileText( pref->rx_endoffile );
 	setNoVideoText( pref->rx_novideo );
+
+	setUseShortNames( pref->use_short_pathnames );
 }
 
 void PrefAdvanced::getData(Preferences * pref) {
 	requires_restart = false;
 	clearing_background_changed = false;
-	colorkey_changed = false;
 	monitor_aspect_changed = false;
+#if USE_COLORKEY
+	colorkey_changed = false;
+#endif
 
 	if (pref->monitor_aspect != monitorAspect()) {
 		pref->monitor_aspect = monitorAspect();
@@ -116,12 +136,13 @@ void PrefAdvanced::getData(Preferences * pref) {
 	TEST_AND_SET(pref->mplayer_additional_options, mplayerAdditionalArguments());
 	TEST_AND_SET(pref->mplayer_additional_video_filters, mplayerAdditionalVideoFilters());
 	TEST_AND_SET(pref->mplayer_additional_audio_filters, mplayerAdditionalAudioFilters());
+#if USE_COLORKEY
 	if (pref->color_key != colorKey()) {
 		pref->color_key = colorKey();
 		colorkey_changed = true;
 		requires_restart = true;
 	}
-
+#endif
 	pref->log_mplayer = logMplayer();
 	pref->log_smplayer = logSmplayer();
 	pref->log_filter = logFilter();
@@ -130,6 +151,8 @@ void PrefAdvanced::getData(Preferences * pref) {
 
 	TEST_AND_SET(pref->rx_endoffile, endOfFileText());
 	TEST_AND_SET(pref->rx_novideo, noVideoText());
+
+	pref->use_short_pathnames = useShortNames();
 }
 
 void PrefAdvanced::setMonitorAspect(QString asp) {
@@ -163,6 +186,14 @@ bool PrefAdvanced::useMplayerWindow() {
 	return mplayer_use_window_check->isChecked();
 }
 
+void PrefAdvanced::setUseShortNames(bool b) {
+	shortnames_check->setChecked(b);
+}
+
+bool PrefAdvanced::useShortNames() {
+	return shortnames_check->isChecked();
+}
+
 void PrefAdvanced::setMplayerAdditionalArguments(QString args) {
 	mplayer_args_edit->setText(args);
 }
@@ -187,6 +218,7 @@ QString PrefAdvanced::mplayerAdditionalAudioFilters() {
 	return mplayer_afilters_edit->text();
 }
 
+#if USE_COLORKEY
 void PrefAdvanced::setColorKey(unsigned int c) {
 	QString color = QString::number(c, 16);
 	while (color.length() < 6) color = "0"+color;
@@ -207,6 +239,7 @@ unsigned int PrefAdvanced::colorKey() {
 
 	return color;
 }
+#endif
 
 void PrefAdvanced::on_changeButton_clicked() {
 	//bool ok;
@@ -282,13 +315,11 @@ QString PrefAdvanced::noVideoText() {
 void PrefAdvanced::createHelp() {
 	clearHelp();
 
-	// Advanced tab
-	setWhatsThis(not_clear_background_check, 
-        tr("Don't repaint the background of the video window"),
-		tr("Checking this option may reduce flickering, but it also might "
-           "produce that the video won't be displayed properly.") );
+	addSectionTitle(tr("Advanced"));
+
+	setWhatsThis(monitoraspect_combo, tr("Monitor aspect"),
+        tr("Select the aspect ratio of your monitor.") );
 
-	// Log tab
 	setWhatsThis(log_smplayer_check, tr("Log SMPlayer output"),
 		tr("If this option is checked, smplayer will store the debugging "
            "messages that smplayer outputs "
@@ -317,6 +348,56 @@ void PrefAdvanced::createHelp() {
            "be stored in the log. Here you can write any regular expression.<br>"
            "For instance: <i>^Core::.*</i> will display only the lines "
            "starting with <i>Core::</i>") );
+
+	setWhatsThis(mplayer_use_window_check, tr("Run MPlayer in its own window"),
+        tr("If you check this option, the MPlayer video window won't be "
+           "embedded in SMPlayer's main window but instead it will use its "
+           "own window. Note that mouse and keyboard events will be handled "
+           "directly by MPlayer, that means key shortcuts and mouse clicks "
+           "probably won't work as expected when the MPlayer window has the "
+           "focus.") );
+
+	setWhatsThis(not_clear_background_check, 
+        tr("Don't repaint the background of the video window"),
+		tr("Checking this option may reduce flickering, but it also might "
+           "produce that the video won't be displayed properly.") );
+
+#ifdef Q_OS_WIN
+	setWhatsThis(shortnames_check, tr("Pass short filenames (8+3) to MPlayer"),
+		tr("Currently MPlayer can't open filenames which contains characters "
+           "outside the local codepage. Checking this option will make "
+           "SMPlayer to pass to MPlayer the short version of the filenames, "
+           "and thus it will able to open them.") );
+#endif
+
+#if USE_COLORKEY
+	setWhatsThis(colorkey_view, tr("Colorkey"),
+        tr("If you see parts of the video over any other window, you can "
+           "change the colorkey to fix it. Try to select a color close to "
+           "black.") );
+#endif
+
+	addSectionTitle(tr("Options for MPlayer"));
+
+	setWhatsThis(mplayer_args_edit, tr("Options"),
+        tr("Here you can type options for MPlayer. Write them separated "
+           "by spaces.") );
+
+	setWhatsThis(mplayer_vfilters_edit, tr("Video filters"),
+        tr("Here you can add video filters for MPlayer. Write them separated "
+           "by commas. Don't use spaces!") );
+
+	setWhatsThis(mplayer_afilters_edit, tr("Audio filters"),
+        tr("Here you can add audio filters for MPlayer. Write them separated "
+           "by commas. Don't use spaces!") );
+
+	addSectionTitle(tr("MPlayer language"));
+
+	setWhatsThis(endoffile_combo, tr("End of file"),
+        tr("Select or type a regular expression for 'End of file'") );
+
+	setWhatsThis(novideo_combo, tr("No video"),
+        tr("Select or type a regular expression for 'No video'") );
 }
 
 #include "moc_prefadvanced.cpp"
