@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "ui_prefadvanced.h"
 #include "prefwidget.h"
+#include "config.h"
 
 class Preferences;
 
@@ -42,8 +43,10 @@ public:
     void getData(Preferences * pref);
 
 	bool clearingBackgroundChanged() { return clearing_background_changed; };
-	bool colorkeyChanged() { return colorkey_changed; };
 	bool monitorAspectChanged() { return monitor_aspect_changed; };
+#if USE_COLORKEY
+	bool colorkeyChanged() { return colorkey_changed; };
+#endif
 
 protected:
 	virtual void createHelp();
@@ -58,6 +61,10 @@ protected:
 	void setUseMplayerWindow(bool v);
 	bool useMplayerWindow();
 
+	// Windows only: pass to mplayer short filenames (8+3)
+	void setUseShortNames(bool b);
+	bool useShortNames();
+
 	void setMplayerAdditionalArguments(QString args);
 	QString mplayerAdditionalArguments();
 
@@ -67,8 +74,10 @@ protected:
 	void setMplayerAdditionalAudioFilters(QString s);
 	QString mplayerAdditionalAudioFilters();
 
+#if USE_COLORKEY
 	void setColorKey(unsigned int c);
 	unsigned int colorKey();
+#endif
 
 	// Log options
 	void setLogMplayer(bool b);
@@ -101,8 +110,10 @@ protected slots:
 
 private:
 	bool clearing_background_changed;
-	bool colorkey_changed;
 	bool monitor_aspect_changed;
+#if USE_COLORKEY
+	bool colorkey_changed;
+#endif
 };
 
 #endif
