@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,6 +28,9 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 {
 	setupUi(this);
 
+	mplayerbin_edit->setDialogType(FileChooser::GetFileName);
+	screenshot_edit->setDialogType(FileChooser::GetDirectory);
+
 	// Read driver info from InfoReader:
 	InfoReader * i = InfoReader::obj();
 	setDrivers( i->voList(), i->aoList() );
@@ -37,7 +40,6 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 	channels_combo->addItem( "4", MediaSettings::ChSurround );
 	channels_combo->addItem( "6", MediaSettings::ChFull51 );
 
-	//createHelp();
 	retranslateStrings();
 }
 
@@ -62,12 +64,30 @@ void PrefGeneral::retranslateStrings() {
 	channels_combo->setItemText(1, tr("4 (4.0 Surround)") );
 	channels_combo->setItemText(2, tr("6 (5.1 Surround)") );
 
+	int deinterlace_item = deinterlace_combo->currentIndex();
+	deinterlace_combo->clear();
+	deinterlace_combo->addItem( tr("None"), MediaSettings::NoDeinterlace );
+	deinterlace_combo->addItem( tr("Lowpass5"), MediaSettings::L5 );
+	deinterlace_combo->addItem( tr("Yadif (normal)"), MediaSettings::Yadif );
+	deinterlace_combo->addItem( tr("Yadif (double framerate)"), MediaSettings::Yadif_1 );
+	deinterlace_combo->addItem( tr("Linear Blend"), MediaSettings::LB );
+	deinterlace_combo->addItem( tr("Kerndeint"), MediaSettings::Kerndeint );
+	deinterlace_combo->setCurrentIndex(deinterlace_item);
+
     // Icons
 	/*
     resize_window_icon->setPixmap( Images::icon("resize_window") );
     volume_icon->setPixmap( Images::icon("speaker") );
 	*/
 
+	mplayerbin_edit->setCaption(tr("Select the mplayer executable"));
+#ifdef Q_OS_WIN
+	mplayerbin_edit->setFilter(tr("Executables") +" (*.exe)");
+#else
+	mplayerbin_edit->setFilter(tr("All files") +" (*)");
+#endif
+	screenshot_edit->setCaption(tr("Select a directory"));
+
 	preferred_desc->setText(
 		tr("Here you can type your preferred language for the audio "
            "and subtitle streams. When a media with multiple audio or "
@@ -101,6 +121,7 @@ void PrefGeneral::setData(Preferences * pref) {
 	setInitialVolNorm( pref->initial_volnorm );
 	setAmplification( pref->softvol_max );
 	setInitialPostprocessing( pref->initial_postprocessing );
+	setInitialDeinterlace( pref->initial_deinterlace );
 	setDirectRendering( pref->use_direct_rendering );
 	setDoubleBuffer( pref->use_double_buffer );
 	setStartInFullscreen( pref->start_in_fullscreen );
@@ -109,6 +130,7 @@ void PrefGeneral::setData(Preferences * pref) {
 
 	setInitialVolume( pref->initial_volume );
 	setDontChangeVolume( pref->dont_change_volume );
+	setUseVolume( pref->use_volume_option2 );
 	setAudioChannels( pref->initial_audio_channels );
 	setScaleTempoFilter( pref->use_scaletempo );
 }
@@ -116,7 +138,18 @@ void PrefGeneral::setData(Preferences * pref) {
 void PrefGeneral::getData(Preferences * pref) {
 	requires_restart = false;
 
-	TEST_AND_SET(pref->mplayer_bin, mplayerPath());
+	if (pref->mplayer_bin != mplayerPath()) {
+		requires_restart = true;
+		pref->mplayer_bin = mplayerPath();
+
+		qDebug("PrefGeneral::getData: mplayer binary has changed, getting version number");
+		// Forces to get info from mplayer to update version number
+		InfoReader i( pref->mplayer_bin );
+		i.getInfo(); 
+		// Update the drivers list at the same time
+		//setDrivers( i.voList(), i.aoList() );
+	}
+
 	TEST_AND_SET(pref->screenshot_directory, screenshotDir());
 	TEST_AND_SET(pref->vo, VO());
     TEST_AND_SET(pref->ao, AO());
@@ -140,6 +173,7 @@ void PrefGeneral::getData(Preferences * pref) {
 	pref->initial_volnorm = initialVolNorm();
 	TEST_AND_SET(pref->softvol_max, amplification());
 	pref->initial_postprocessing = initialPostprocessing();
+	pref->initial_deinterlace = initialDeinterlace();
 	TEST_AND_SET(pref->use_direct_rendering, directRendering());
 	TEST_AND_SET(pref->use_double_buffer, doubleBuffer());
 	pref->start_in_fullscreen = startInFullscreen();
@@ -148,23 +182,33 @@ void PrefGeneral::getData(Preferences * pref) {
 
 	pref->initial_volume = initialVolume();
 	pref->dont_change_volume = dontChangeVolume();
+	pref->use_volume_option2 = useVolume();
 	pref->initial_audio_channels = audioChannels();
 	TEST_AND_SET(pref->use_scaletempo, scaleTempoFilter());
 }
 
 void PrefGeneral::setDrivers(InfoList vo_list, InfoList ao_list) {
-	InfoList::iterator it;
-
-	for ( it = vo_list.begin(); it != vo_list.end(); ++it ) {
-		vo_combo->addItem( (*it).name() );
+	for ( int n = 0; n < vo_list.count(); n++ ) {
+		vo_combo->addItem( vo_list[n].name() );
 		// Add directx:noaccel
-		if ( (*it).name() == "directx" ) {
+		if ( vo_list[n].name() == "directx" ) {
 			vo_combo->addItem( "directx:noaccel" );
 		}
+		// gl/gl2
+		if (vo_list[n].name() == "gl") {
+			vo_combo->addItem( "gl:yuv=3" );
+			vo_combo->addItem( "gl:yuv=2:force-pbo:ati-hack" );
+			//vo_combo->addItem( "gl:yuv=3:lscale=1" );
+		}
+		/*
+		if (vo_list[n].name() == "gl2") {
+			vo_combo->addItem( "gl2:yuv=3" );
+		}
+		*/
 	}
 
-	for ( it = ao_list.begin(); it != ao_list.end(); ++it ) {
-		ao_combo->addItem( (*it).name() );
+	for ( int n = 0; n < ao_list.count(); n++) {
+		ao_combo->addItem( ao_list[n].name() );
 	}
 }
 
@@ -306,6 +350,24 @@ bool PrefGeneral::initialPostprocessing() {
 	return postprocessing_check->isChecked();
 }
 
+void PrefGeneral::setInitialDeinterlace(int ID) {
+	int pos = deinterlace_combo->findData(ID);
+	if (pos != -1) {
+		deinterlace_combo->setCurrentIndex(pos);
+	} else {
+		qWarning("PrefGeneral::setInitialDeinterlace: ID: %d not found in combo", ID);
+	}
+}
+
+int PrefGeneral::initialDeinterlace() {
+	if (deinterlace_combo->currentIndex() != -1) {
+		return deinterlace_combo->itemData( deinterlace_combo->currentIndex() ).toInt();
+	} else {
+		qWarning("PrefGeneral::initialDeinterlace: no item selected");
+		return 0;
+	}
+}
+
 void PrefGeneral::setDirectRendering(bool b) {
 	direct_rendering_check->setChecked(b);
 }
@@ -364,6 +426,14 @@ bool PrefGeneral::dontChangeVolume() {
 	return !change_volume_check->isChecked();
 }
 
+void PrefGeneral::setUseVolume(Preferences::OptionState value) {
+	use_volume_combo->setState(value);
+}
+
+Preferences::OptionState PrefGeneral::useVolume() {
+	return use_volume_combo->state();
+}
+
 void PrefGeneral::setStartInFullscreen(bool b) {
 	start_fullscreen_check->setChecked(b);
 }
@@ -388,43 +458,19 @@ int PrefGeneral::autoq() {
 	return autoq_spin->value();
 }
 
-void PrefGeneral::setScaleTempoFilter(bool b) {
-	scaletempo_check->setChecked(b);
+void PrefGeneral::setScaleTempoFilter(Preferences::OptionState value) {
+	scaletempo_combo->setState(value);
 }
 
-bool PrefGeneral::scaleTempoFilter() {
-	return scaletempo_check->isChecked();
-}
-
-// Search mplayer executable
-void PrefGeneral::on_searchButton_clicked() {
-	QString	s = MyFileDialog::getOpenFileName(
-                        this, tr("Select the mplayer executable"),
-	                    mplayerbin_edit->text(),
-#ifdef Q_OS_WIN
-    	                tr("Executables") +" (*.exe)"
-#else
-    	                tr("All files") +" (*)"
-#endif
-            	         );
-
-	if (!s.isEmpty()) {
-		mplayerbin_edit->setText(s);
-	}
-}
-
-void PrefGeneral::on_selectButton_clicked() {
-	QString s = MyFileDialog::getExistingDirectory(
-					this, tr("Select a directory"), 
-                    screenshot_edit->text() );
-	if (!s.isEmpty()) {
-		screenshot_edit->setText(s);
-	}
+Preferences::OptionState PrefGeneral::scaleTempoFilter() {
+	return scaletempo_combo->state();
 }
 
 void PrefGeneral::createHelp() {
 	clearHelp();
 
+	addSectionTitle(tr("General"));
+
 	setWhatsThis(mplayerbin_edit, tr("MPlayer executable"), 
 		tr("Here you must specify the mplayer "
            "executable that smplayer will use.<br>"
@@ -462,7 +508,9 @@ void PrefGeneral::createHelp() {
            "main window is hidden. When the window is restored, play will be "
            "resumed.") );
 
-	// Video/audio tab
+	addSectionTitle(tr("Video"));
+
+	// Video tab
 	setWhatsThis(eq2_check, tr("Software video equalizer"),
 		tr("You can check this option if video equalizer is not supported by "
            "your graphic card or the selected video output driver.<br>"
@@ -477,6 +525,10 @@ void PrefGeneral::createHelp() {
            "available spare CPU time. The number you specify will be the "
            "maximum level used. Usually you can use some big number.") );
 
+	setWhatsThis(deinterlace_combo, tr("Deinterlace by default"),
+        tr("Select the deinterlace filter that you want to be used for new "
+           "videos opened.") );
+
 	setWhatsThis(direct_rendering_check, tr("Direct rendering"),
 		tr("If checked, turns on direct rendering (not supported by all "
            "codecs and video outputs)<br>"
@@ -496,6 +548,8 @@ void PrefGeneral::createHelp() {
            "The screensaver will enabled again when play finishes.<br>"
            "<b>Note:</b> This option works only in X11 and Windows.") );
 
+	addSectionTitle(tr("Audio"));
+
 	setWhatsThis(softvol_check, tr("Software volume control"),
 		tr("Check this option to use the software mixer, instead of "
            "using the sound card mixer.") );
@@ -513,10 +567,6 @@ void PrefGeneral::createHelp() {
 	setWhatsThis(volnorm_check, tr("Volume normalization by default"),
 		tr("Maximizes the volume without distorting the sound.") );
 
-	setWhatsThis(scaletempo_check, tr("High speed playback without altering pitch"),
-		tr("Allows to change the playback speed without altering pitch. "
-           "Requires at least MPlayer dev-SVN-r24924.") );
-
 	setWhatsThis(change_volume_check, tr("Change volume"),
 		tr("If checked, SMPlayer will remember the volume for every file "
            "and will restore it when played again. For new files the default "
@@ -525,6 +575,14 @@ void PrefGeneral::createHelp() {
 	setWhatsThis(initial_volume_slider, tr("Default volume"),
 		tr("Sets the initial volume that new files will use.") );
 
+	setWhatsThis(use_volume_combo, tr("Change volume just before playing"),
+		tr("If this option is checked the initial volume will be set by "
+           "using the <i>-volume</i> option in MPlayer.<br> "
+           "<b>WARNING: THE OFFICIAL MPLAYER DOESN'T HAVE THAT "
+           "<i>-volume</i> OPTION, "
+           "YOU NEED A PATCHED ONE, OTHERWISE MPLAYER WILL FAIL AND WON'T PLAY "
+           "ANYTHING.</b>") );
+
 	setWhatsThis(channels_combo, tr("Channels by default"),
 		tr("Requests the number of playback channels. MPlayer "
            "asks the decoder to decode the audio into as many channels as "
@@ -536,6 +594,12 @@ void PrefGeneral::createHelp() {
            "NOTE: This option is honored by codecs (AC3 only), "
            "filters (surround) and audio output drivers (OSS at least).") );
 
+	setWhatsThis(scaletempo_combo, tr("High speed playback without altering pitch"),
+		tr("Allows to change the playback speed without altering pitch. "
+           "Requires at least MPlayer dev-SVN-r24924.") );
+
+	addSectionTitle(tr("Preferred audio and subtitles"));
+
 	setWhatsThis(audio_lang_edit, tr("Preferred audio language"),
 		tr("Here you can type your preferred language for the audio streams. "
            "When a media with multiple audio streams is found, smplayer will "
