@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,8 +22,7 @@
 #include "ui_prefgeneral.h"
 #include "prefwidget.h"
 #include "inforeader.h"
-
-class Preferences;
+#include "preferences.h"
 
 class PrefGeneral : public PrefWidget, public Ui::PrefGeneral
 {
@@ -111,6 +110,9 @@ protected:
 	void setInitialPostprocessing(bool b);
 	bool initialPostprocessing();
 
+	void setInitialDeinterlace(int ID);
+	int initialDeinterlace();
+
 	void setDirectRendering(bool b);
 	bool directRendering();
 
@@ -126,18 +128,18 @@ protected:
 	void setDontChangeVolume(bool b);
 	bool dontChangeVolume();
 
+	// Use -volume option
+	void setUseVolume(Preferences::OptionState value);
+	Preferences::OptionState useVolume();
+
 	void setAudioChannels(int ID);
 	int audioChannels();
 
-	void setScaleTempoFilter(bool b);
-	bool scaleTempoFilter();
+	void setScaleTempoFilter(Preferences::OptionState value);
+	Preferences::OptionState scaleTempoFilter();
 
 protected:
 	virtual void retranslateStrings();
-
-protected slots:
-	void on_searchButton_clicked();
-	void on_selectButton_clicked();
 };
 
 #endif
