@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #include "images.h"
 #include "preferences.h"
 
-#include "config.h"
+#include "guiconfig.h"
 
 PrefInput::PrefInput(QWidget * parent, Qt::WindowFlags f)
 	: PrefWidget(parent, f )
@@ -47,6 +47,8 @@ void PrefInput::createMouseCombos() {
 	left_click_combo->clear();
 	double_click_combo->clear();
 	middle_click_combo->clear();
+	xbutton1_click_combo->clear();
+	xbutton2_click_combo->clear();
 
 	left_click_combo->addItem( tr("None"), "" );
 	left_click_combo->addItem( tr("Play"), "play" );
@@ -54,24 +56,44 @@ void PrefInput::createMouseCombos() {
 	left_click_combo->addItem( tr("Pause"), "pause" );
 	left_click_combo->addItem( tr("Pause / Frame step"), "pause_and_frame_step" );
 	left_click_combo->addItem( tr("Stop"), "stop" );
+	left_click_combo->addItem( tr("Go backward (short)"), "rewind1" );
+	left_click_combo->addItem( tr("Go backward (medium)"), "rewind2" );
+	left_click_combo->addItem( tr("Go backward (long)"), "rewind3" );
+	left_click_combo->addItem( tr("Go forward (short)"), "forward1" );
+	left_click_combo->addItem( tr("Go forward (medium)"), "forward2" );
+	left_click_combo->addItem( tr("Go forward (long)"), "forward3" );
 	left_click_combo->addItem( tr("Fullscreen"), "fullscreen" );
 	left_click_combo->addItem( tr("Compact"), "compact" );
 	left_click_combo->addItem( tr("Screenshot"), "screenshot" );
 	left_click_combo->addItem( tr("On top"), "on_top" );
 	left_click_combo->addItem( tr("Mute"), "mute" );
+	left_click_combo->addItem( tr("OSD - Next level"), "next_osd" );
 	left_click_combo->addItem( tr("Playlist"), "show_playlist" );
-	left_click_combo->addItem( tr("Frame counter"), "frame_counter" );
-	left_click_combo->addItem( tr("Preferences"), "show_preferences" );
 	left_click_combo->addItem( tr("Reset zoom"), "reset_zoom" );
 	left_click_combo->addItem( tr("Exit fullscreen"), "exit_fullscreen" );
+	left_click_combo->addItem( tr("Normal speed"), "normal_speed" );
+	left_click_combo->addItem( tr("Frame counter"), "frame_counter" );
+	left_click_combo->addItem( tr("Preferences"), "show_preferences" );
 	left_click_combo->addItem( tr("Double size"), "toggle_double_size" );
+	left_click_combo->addItem( tr("Show equalizer"), "equalizer" );
+	left_click_combo->addItem( tr("Show context menu"), "show_context_menu" );
 
 	// Copy to other combos
 	for (int n=0; n < left_click_combo->count(); n++) {
 		double_click_combo->addItem( left_click_combo->itemText(n),
                                      left_click_combo->itemData(n) );
+
+		right_click_combo->addItem( left_click_combo->itemText(n),
+                                    left_click_combo->itemData(n) );
+
 		middle_click_combo->addItem( left_click_combo->itemText(n),
                                      left_click_combo->itemData(n) );
+
+		xbutton1_click_combo->addItem( left_click_combo->itemText(n),
+                                       left_click_combo->itemData(n) );
+
+		xbutton2_click_combo->addItem( left_click_combo->itemText(n),
+                                       left_click_combo->itemData(n) );
 	}
 }
 
@@ -85,12 +107,20 @@ void PrefInput::retranslateStrings() {
 
     // Mouse function combos
 	int mouse_left = left_click_combo->currentIndex();
+	int mouse_right = right_click_combo->currentIndex();
 	int mouse_double = double_click_combo->currentIndex();
 	int mouse_middle = middle_click_combo->currentIndex();
+	int mouse_xclick1 = xbutton1_click_combo->currentIndex();
+	int mouse_xclick2 = xbutton2_click_combo->currentIndex();
+
 	createMouseCombos();
+
 	left_click_combo->setCurrentIndex(mouse_left);
+	right_click_combo->setCurrentIndex(mouse_right);
 	double_click_combo->setCurrentIndex(mouse_double);
 	middle_click_combo->setCurrentIndex(mouse_middle);
+	xbutton1_click_combo->setCurrentIndex(mouse_xclick1);
+	xbutton2_click_combo->setCurrentIndex(mouse_xclick2);
 
 	wheel_function_combo->clear();
 	wheel_function_combo->addItem( tr("No function"), Preferences::DoNothing );
@@ -113,8 +143,11 @@ void PrefInput::retranslateStrings() {
 
 void PrefInput::setData(Preferences * pref) {
 	setLeftClickFunction( pref->mouse_left_click_function );
+	setRightClickFunction( pref->mouse_right_click_function );
 	setDoubleClickFunction( pref->mouse_double_click_function );
 	setMiddleClickFunction( pref->mouse_middle_click_function );
+	setXButton1ClickFunction( pref->mouse_xbutton1_click_function );
+	setXButton2ClickFunction( pref->mouse_xbutton2_click_function );
 	setWheelFunction( pref->wheel_function );
 }
 
@@ -122,8 +155,11 @@ void PrefInput::getData(Preferences * pref) {
 	requires_restart = false;
 
 	pref->mouse_left_click_function = leftClickFunction();
+	pref->mouse_right_click_function = rightClickFunction();
 	pref->mouse_double_click_function = doubleClickFunction();
 	pref->mouse_middle_click_function = middleClickFunction();
+	pref->mouse_xbutton1_click_function = xButton1ClickFunction();
+	pref->mouse_xbutton2_click_function = xButton2ClickFunction();
 	pref->wheel_function = wheelFunction();
 }
 
@@ -144,6 +180,16 @@ QString PrefInput::leftClickFunction() {
 	return left_click_combo->itemData( left_click_combo->currentIndex() ).toString();
 }
 
+void PrefInput::setRightClickFunction(QString f) {
+	int pos = right_click_combo->findData(f);
+	if (pos == -1) pos = 0; //None
+	right_click_combo->setCurrentIndex(pos);
+}
+
+QString PrefInput::rightClickFunction() {
+	return right_click_combo->itemData( right_click_combo->currentIndex() ).toString();
+}
+
 void PrefInput::setDoubleClickFunction(QString f) {
 	int pos = double_click_combo->findData(f);
 	if (pos == -1) pos = 0; //None
@@ -164,6 +210,26 @@ QString PrefInput::middleClickFunction() {
 	return middle_click_combo->itemData( middle_click_combo->currentIndex() ).toString();
 }
 
+void PrefInput::setXButton1ClickFunction(QString f) {
+	int pos = xbutton1_click_combo->findData(f);
+	if (pos == -1) pos = 0; //None
+	xbutton1_click_combo->setCurrentIndex(pos);
+}
+
+QString PrefInput::xButton1ClickFunction() {
+	return xbutton1_click_combo->itemData( xbutton1_click_combo->currentIndex() ).toString();
+}
+
+void PrefInput::setXButton2ClickFunction(QString f) {
+	int pos = xbutton2_click_combo->findData(f);
+	if (pos == -1) pos = 0; //None
+	xbutton2_click_combo->setCurrentIndex(pos);
+}
+
+QString PrefInput::xButton2ClickFunction() {
+	return xbutton2_click_combo->itemData( xbutton2_click_combo->currentIndex() ).toString();
+}
+
 void PrefInput::setWheelFunction(int function) {
 	int d = wheel_function_combo->findData(function);
 	if (d < 0) d = 0;
@@ -177,6 +243,8 @@ int PrefInput::wheelFunction() {
 void PrefInput::createHelp() {
 	clearHelp();
 
+	addSectionTitle(tr("Keyboard"));
+
 	setWhatsThis(actions_editor, tr("Shortcut editor"),
         tr("This table allows you to change the key shortcuts of most "
            "available actions. Double click or press enter on a item, or "
@@ -188,12 +256,17 @@ void PrefInput::createHelp() {
            "keys). If the <b>Capture</b> button is off "
            "then you could enter the full name of the key.") );
 
+	addSectionTitle(tr("Mouse"));
+
 	setWhatsThis(left_click_combo, tr("Left click"),
 		tr("Select the action for left click on the mouse.") );
 
 	setWhatsThis(double_click_combo, tr("Double click"),
 		tr("Select the action for double click on the mouse.") );
 
+	setWhatsThis(middle_click_combo, tr("Middle click"),
+		tr("Select the action for middle click on the mouse.") );
+
 	setWhatsThis(wheel_function_combo, tr("Wheel function"),
 		tr("Select the action for the mouse wheel.") );
 }
