@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -62,6 +62,9 @@ PrefInterface::PrefInterface(QWidget * parent, Qt::WindowFlags f)
 		}
 	}
 
+	connect(single_instance_check, SIGNAL(toggled(bool)), 
+            this, SLOT(changeInstanceImages()));
+
 	retranslateStrings();
 }
 
@@ -94,6 +97,8 @@ void PrefInterface::createLanguageCombo() {
 	m["it"] = tr("Italian");
 	m["ja"] = tr("Japanese");
 	m["ka"] = tr("Georgian");
+	m["ko"] = tr("Korean");
+	m["mk"] = tr("Macedonian");
 	m["nl"] = tr("Dutch");
 	m["pl"] = tr("Polish");
 	m["pt_BR"] = tr("Portuguese - Brazil");
@@ -126,15 +131,19 @@ void PrefInterface::createLanguageCombo() {
 
 void PrefInterface::retranslateStrings() {
 	int mainwindow_resize = mainwindow_resize_combo->currentIndex();
+	int timeslider_pos = timeslider_behaviour_combo->currentIndex();
 
 	retranslateUi(this);
 
 	mainwindow_resize_combo->setCurrentIndex(mainwindow_resize);
+	timeslider_behaviour_combo->setCurrentIndex(timeslider_pos);
 
 	// Icons
-	/* resize_window_icon->setPixmap( Images::icon("resize_window") ); */
+	resize_window_icon->setPixmap( Images::icon("resize_window") );
 	/* volume_icon->setPixmap( Images::icon("speaker") ); */
 
+	changeInstanceImages();
+
 	// Seek widgets
 	seek1->setLabel( tr("&Short jump") );
 	seek2->setLabel( tr("&Medium jump") );
@@ -150,7 +159,7 @@ void PrefInterface::retranslateStrings() {
 		seek2->setIcon( Images::flippedIcon("forward1m") );
 		seek3->setIcon( Images::flippedIcon("forward10m") );
 	}
-	seek4->setIcon( Images::icon("mouse_small") );
+	seek4->setIcon( Images::icon("mouse", seek1->icon()->width()) );
 
 	// Language combo
 	int language_item = language_combo->currentIndex();
@@ -164,6 +173,12 @@ void PrefInterface::retranslateStrings() {
 	style_combo->setItemText( 0, tr("Default") );
 #endif
 
+	int gui_index = gui_combo->currentIndex();
+	gui_combo->clear();
+	gui_combo->addItem( tr("Default GUI"), "DefaultGUI");
+	gui_combo->addItem( tr("Mini GUI"), "MiniGUI");
+	gui_combo->setCurrentIndex(gui_index);
+
 	createHelp();
 }
 
@@ -182,11 +197,15 @@ void PrefInterface::setData(Preferences * pref) {
 	setSeeking3(pref->seeking3);
 	setSeeking4(pref->seeking4);
 
+	setUpdateWhileDragging(pref->update_while_seeking);
+
 	setDefaultFont(pref->default_font);
 
 #if STYLE_SWITCHING
 	setStyle( pref->style );
 #endif
+
+	setGUI(pref->gui);
 }
 
 void PrefInterface::getData(Preferences * pref) {
@@ -227,6 +246,8 @@ void PrefInterface::getData(Preferences * pref) {
 	pref->seeking3 = seeking3();
 	pref->seeking4 = seeking4();
 
+	pref->update_while_seeking = updateWhileDragging();
+
 	pref->default_font = defaultFont();
 
 #if STYLE_SWITCHING
@@ -235,6 +256,8 @@ void PrefInterface::getData(Preferences * pref) {
 		style_changed = true;
 	}
 #endif
+
+	pref->gui = GUI();
 }
 
 void PrefInterface::setLanguage(QString lang) {
@@ -302,6 +325,16 @@ QString PrefInterface::style() {
 		return style_combo->currentText();
 }
 
+void PrefInterface::setGUI(QString gui_name) {
+	int i = gui_combo->findData(gui_name);
+	if (i < 0) i=0;
+	gui_combo->setCurrentIndex(i);
+}
+
+QString PrefInterface::GUI() {
+	return gui_combo->itemData(gui_combo->currentIndex()).toString();
+}
+
 void PrefInterface::setUseSingleInstance(bool b) {
 	single_instance_check->setChecked(b);
 	//singleInstanceButtonToggled(b);
@@ -359,6 +392,17 @@ int PrefInterface::seeking4() {
 	return seek4->time();
 }
 
+void PrefInterface::setUpdateWhileDragging(bool b) {
+	if (b) 
+		timeslider_behaviour_combo->setCurrentIndex(0);
+	else
+		timeslider_behaviour_combo->setCurrentIndex(1);
+}
+
+bool PrefInterface::updateWhileDragging() {
+	return (timeslider_behaviour_combo->currentIndex() == 0);
+}
+
 void PrefInterface::setDefaultFont(QString font_desc) {
 	default_font_edit->setText(font_desc);
 }
@@ -382,11 +426,85 @@ void PrefInterface::on_changeFontButton_clicked() {
 	}
 }
 
+void PrefInterface::changeInstanceImages() {
+	if (single_instance_check->isChecked())
+		instances_icon->setPixmap( Images::icon("instance1") );
+	else
+		instances_icon->setPixmap( Images::icon("instance2") );
+}
+
 void PrefInterface::createHelp() {
 	clearHelp();
 
+	addSectionTitle(tr("Interface"));
+
+	setWhatsThis(mainwindow_resize_combo, tr("Autoresize"),
+        tr("The main window can be resized automatically. Select the option "
+           "you prefer.") );
+
+	setWhatsThis(save_size_check, tr("Remember position and size"),
+        tr("If you check this option, the position and size of the main "
+           "window will be saved and restored when you run SMPlayer again.") );
+
+	setWhatsThis(recents_max_items_spin, tr("Recent files"),
+        tr("Select the maximum number of items that will be shown in the "
+           "<b>Open->Recent files</b> submenu. If you set it to 0 that "
+           "menu won't be shown at all.") );
+
 	setWhatsThis(language_combo, tr("Language"),
 		tr("Here you can change the language of the application.") );
+
+	setWhatsThis(iconset_combo, tr("Icon set"),
+        tr("Select the icon set you prefer for the application.") );
+
+	setWhatsThis(style_combo, tr("Style"),
+        tr("Select the style you prefer for the application.") );
+
+	setWhatsThis(gui_combo, tr("GUI"),
+        tr("Select the GUI you prefer for the application. Currently "
+           "there are two available: Default GUI and Mini GUI.<br>"
+           "The <b>Default GUI</b> provides the traditional GUI, with the "
+           "toolbar and control bar. The <b>Mini GUI</b> provides a "
+           "more simple GUI, without toolbar and a control bar with few "
+           "buttons.<br>"
+           "<b>Note:</b> this option will take effect the next "
+           "time you run SMPlayer.") );
+
+	setWhatsThis(changeFontButton, tr("Default font"),
+        tr("You can change here the application's font.") );
+
+	addSectionTitle(tr("Seeking"));
+
+	setWhatsThis(seek1, tr("Short jump"),
+        tr("Select the time that should be go forward or backward when you "
+           "choose the %1 action.").arg(tr("short jump")) );
+
+	setWhatsThis(seek2, tr("Medium jump"),
+        tr("Select the time that should be go forward or backward when you "
+           "choose the %1 action.").arg(tr("medium jump")) );
+
+	setWhatsThis(seek3, tr("Long jump"),
+        tr("Select the time that should be go forward or backward when you "
+           "choose the %1 action.").arg(tr("long jump")) );
+
+	setWhatsThis(seek4, tr("Mouse wheel jump"),
+        tr("Select the time that should be go forward or backward when you "
+           "move the mouse wheel.") );
+
+	setWhatsThis(timeslider_behaviour_combo, tr("Behaviour of time slider"),
+        tr("Select what to do when dragging the time slider.") );
+
+	addSectionTitle(tr("Instances"));
+
+	setWhatsThis(single_instance_check, 
+        tr("Use only one running instance of SMPlayer"),
+        tr("Check this option if you want to use an already running instance "
+           "of SMPlayer when opening other files.") );
+
+	setWhatsThis(server_port_spin, tr("Port"),
+        tr("SMPlayer needs to listen to a port to receive commands from other "
+           "instances. You can change the port in case the default one is "
+           "used by another application.") );
 }
 
 #include "moc_prefinterface.cpp"
