@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,6 +63,9 @@ protected:
 	void setSaveSize(bool b);
 	bool saveSize();
 
+	void setGUI(QString gui_name);
+	QString GUI();
+
 	void setStyle(QString style);
 	QString style();
 
@@ -87,11 +90,15 @@ protected:
 	void setSeeking4(int n);
 	int seeking4();
 
+	void setUpdateWhileDragging(bool);
+	bool updateWhileDragging();
+
 	void setDefaultFont(QString font_desc);
 	QString defaultFont();
 
 protected slots:
 	void on_changeFontButton_clicked();
+	void changeInstanceImages();
 
 protected:
 	virtual void retranslateStrings();
