@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,8 +19,10 @@
 
 #include "prefperformance.h"
 #include "images.h"
+#include "global.h"
 #include "preferences.h"
 
+using namespace Global;
 
 PrefPerformance::PrefPerformance(QWidget * parent, Qt::WindowFlags f)
 	: PrefWidget(parent, f )
@@ -32,10 +34,11 @@ PrefPerformance::PrefPerformance(QWidget * parent, Qt::WindowFlags f)
 	priority_group->hide();
 #endif
 
-	// This option is not good. Playing is awful, even with no H.264 videos.
-	skip_frames_check->hide();
+#if SMART_DVD_CHAPTERS
+	fast_chapter_check->hide();
+#endif
 
-	createHelp();
+	retranslateStrings();
 }
 
 PrefPerformance::~PrefPerformance()
@@ -53,25 +56,35 @@ QPixmap PrefPerformance::sectionIcon() {
 
 void PrefPerformance::retranslateStrings() {
 	int priority = priority_combo->currentIndex();
+	int loop_filter = loopfilter_combo->currentIndex();
 
 	retranslateUi(this);
 
+	loopfilter_combo->clear();
+	loopfilter_combo->addItem( tr("Enabled"), Preferences::LoopEnabled );
+	loopfilter_combo->addItem( tr("Skip (always)"), Preferences::LoopDisabled );
+	loopfilter_combo->addItem( tr("Skip only on HD videos"), Preferences::LoopDisabledOnHD );
+
 	priority_combo->setCurrentIndex(priority);
+	loopfilter_combo->setCurrentIndex(loop_filter);
 
 	createHelp();
 }
 
 void PrefPerformance::setData(Preferences * pref) {
-	setCacheEnabled( pref->use_cache );
-	setCache( pref->cache );
+	setCacheForFiles( pref->cache_for_files );
+	setCacheForStreams( pref->cache_for_streams );
+	setCacheForDVDs( pref->cache_for_dvds );
+
 	setPriority( pref->priority );
 	setFrameDrop( pref->frame_drop );
 	setHardFrameDrop( pref->hard_frame_drop );
-	setSkipLoop( pref->h264_skip_loop );
-	/* setSkipFrames( pref->h264_skip_frames ); */
+	setSkipLoop( pref->h264_skip_loop_filter );
 	setAutoSyncActivated( pref->autosync );
 	setAutoSyncFactor( pref->autosync_factor );
+#if !SMART_DVD_CHAPTERS
 	setFastChapterSeeking( pref->fast_chapter_change );
+#endif
 	setFastAudioSwitching( pref->fast_audio_change );
 	setUseIdx( pref->use_idx );
 }
@@ -79,36 +92,48 @@ void PrefPerformance::setData(Preferences * pref) {
 void PrefPerformance::getData(Preferences * pref) {
 	requires_restart = false;
 
-	TEST_AND_SET(pref->use_cache, cacheEnabled());
-	TEST_AND_SET(pref->cache, cache());
+	TEST_AND_SET(pref->cache_for_files, cacheForFiles());
+	TEST_AND_SET(pref->cache_for_streams, cacheForStreams());
+	TEST_AND_SET(pref->cache_for_dvds, cacheForDVDs());
+
 	TEST_AND_SET(pref->priority, priority());
 	TEST_AND_SET(pref->frame_drop, frameDrop());
 	TEST_AND_SET(pref->hard_frame_drop, hardFrameDrop());
-	TEST_AND_SET(pref->h264_skip_loop, skipLoop());
-	/* TEST_AND_SET(pref->h264_skip_frames, skipFrames()); */
+	TEST_AND_SET(pref->h264_skip_loop_filter, skipLoop());
 	TEST_AND_SET(pref->autosync, autoSyncActivated());
 	TEST_AND_SET(pref->autosync_factor, autoSyncFactor());
+#if !SMART_DVD_CHAPTERS
 	TEST_AND_SET(pref->fast_chapter_change, fastChapterSeeking());
+#endif
 	pref->fast_audio_change = fastAudioSwitching();
 	TEST_AND_SET(pref->use_idx, useIdx());
 }
 
-void PrefPerformance::setCacheEnabled(bool b) {
-	use_cache_check->setChecked(b);
+void PrefPerformance::setCacheForFiles(int n) {
+	cache_files_spin->setValue(n);
 }
 
-bool PrefPerformance::cacheEnabled() {
-	return use_cache_check->isChecked();
+int PrefPerformance::cacheForFiles() {
+	return cache_files_spin->value();
 }
 
-void PrefPerformance::setCache(int n) {
-	cache_spin->setValue(n);
+void PrefPerformance::setCacheForStreams(int n) {
+	cache_streams_spin->setValue(n);
 }
 
-int PrefPerformance::cache() {
-	return cache_spin->value();
+int PrefPerformance::cacheForStreams() {
+	return cache_streams_spin->value();
 }
 
+void PrefPerformance::setCacheForDVDs(int n) {
+	cache_dvds_spin->setValue(n);
+}
+
+int PrefPerformance::cacheForDVDs() {
+	return cache_dvds_spin->value();
+}
+
+
 void PrefPerformance::setPriority(int n) {
 	priority_combo->setCurrentIndex(n);
 }
@@ -133,20 +158,12 @@ bool PrefPerformance::hardFrameDrop() {
 	return hardframedrop_check->isChecked();
 }
 
-void PrefPerformance::setSkipLoop(bool b) {
-	skip_loop_filter_check->setChecked(b);
+void PrefPerformance::setSkipLoop(Preferences::H264LoopFilter value) {
+	loopfilter_combo->setCurrentIndex(loopfilter_combo->findData(value));
 }
 
-bool PrefPerformance::skipLoop() {
-	return skip_loop_filter_check->isChecked();
-}
-
-void PrefPerformance::setSkipFrames(bool b) {
-	skip_frames_check->setChecked(b);
-}
-
-bool PrefPerformance::skipFrames() {
-	return skip_frames_check->isChecked();
+Preferences::H264LoopFilter PrefPerformance::skipLoop() {
+	return (Preferences::H264LoopFilter) loopfilter_combo->itemData(loopfilter_combo->currentIndex()).toInt();
 }
 
 void PrefPerformance::setAutoSyncFactor(int factor) {
@@ -165,6 +182,7 @@ bool PrefPerformance::autoSyncActivated() {
 	return autosync_check->isChecked();
 }
 
+#if !SMART_DVD_CHAPTERS
 void PrefPerformance::setFastChapterSeeking(bool b) {
 	fast_chapter_check->setChecked(b);
 }
@@ -172,6 +190,7 @@ void PrefPerformance::setFastChapterSeeking(bool b) {
 bool PrefPerformance::fastChapterSeeking() {
 	return fast_chapter_check->isChecked();
 }
+#endif
 
 void PrefPerformance::setFastAudioSwitching(Preferences::OptionState value) {
 	fast_audio_combo->setState(value);
@@ -192,19 +211,15 @@ bool PrefPerformance::useIdx() {
 void PrefPerformance::createHelp() {
 	clearHelp();
 
+	addSectionTitle(tr("Performance"));
+	
 	// Performance tab
+#ifdef Q_OS_WIN
 	setWhatsThis(priority_combo, tr("Priority"), 
 		tr("Set process priority for mplayer according to the predefined "
            "priorities available under Windows.<br>"
-           "<b>WARNING:</b> Using realtime priority can cause system lockup.")
-#ifndef Q_OS_WIN
-        + tr("<br><b>Note:</b> This option is for Windows only.") 
+           "<b>WARNING:</b> Using realtime priority can cause system lockup."));
 #endif
-		);
-
-	setWhatsThis(cache_spin, tr("Cache"), 
-		tr("This option specifies how much memory (in kBytes) to use when "
-           "precaching a file or URL. Especially useful on slow media.") );
 
 	setWhatsThis(framedrop_check, tr("Allow frame drop"),
 		tr("Skip displaying some frames to maintain A/V sync on slow systems." ) );
@@ -213,19 +228,21 @@ void PrefPerformance::createHelp() {
 		tr("More intense frame dropping (breaks decoding). "
            "Leads to image distortion!") );
 
-	setWhatsThis(skip_loop_filter_check, tr("Skip loop filter"),
-		tr("Skips the loop filter (AKA deblocking) during H.264 decoding. "
+	setWhatsThis(loopfilter_combo, tr("Skip loop filter"),
+		tr("This option allows to skips the loop filter (AKA deblocking) "
+           "during H.264 decoding. "
            "Since the filtered frame is supposed to be used as reference "
            "for decoding dependent frames this has a worse effect on quality "
            "than not doing deblocking on e.g. MPEG-2 video. But at least for "
            "high bitrate HDTV this provides a big speedup with no visible "
-           "quality loss.") );
-
-	/*
-	setWhatsThis(skip_frames_check, tr("Skip frames"),
-		tr("Skips decoding of frames completely. Big speedup, but jerky "
-           "motion and sometimes bad artifacts.") );
-	*/
+           "quality loss.") +"<br>"+
+           tr("Possible values:") +"<br>" +
+           tr("<b>Enabled</b>: the loop filter is not skipped")+"<br>"+
+           tr("<b>Skip (always)</b>: the loop filter is skipped no matter the "
+           "resolution of the video")+"<br>"+
+           tr("<b>Skip only on HD videos</b>: the loop filter will be "
+           "skipped only on videos which height is %1 or "
+           "greater.").arg(pref->HD_height) +"<br>" );
 
 	setWhatsThis(autosync_check, tr("Audio/video auto synchronization"),
 		tr("Gradually adjusts the A/V sync based on audio delay "
@@ -240,9 +257,11 @@ void PrefPerformance::createHelp() {
            "<b>Auto</b>: SMPlayer will decide what to do according to the "
            "MPlayer version." ) );
 
+#if !SMART_DVD_CHAPTERS
 	setWhatsThis(fast_chapter_check, tr("Fast seek to chapters in dvds"),
 		tr("If checked, it will try the fastest method to seek to chapters "
            "but it might not work with some discs.") );
+#endif
 
 	setWhatsThis(idx_check, tr("Create index if needed"),
 		tr("Rebuilds index of files if no index was found, allowing seeking. "
@@ -251,6 +270,20 @@ void PrefPerformance::createHelp() {
            "seeking (i.e. not with stdin, pipe, etc).<br> "
            "Note: the creation of the index may take some time.") );
 
+	addSectionTitle(tr("Cache"));
+
+	setWhatsThis(cache_files_spin, tr("Cache for files"), 
+		tr("This option specifies how much memory (in kBytes) to use when "
+           "precaching a file.") );
+
+	setWhatsThis(cache_streams_spin, tr("Cache for streams"), 
+		tr("This option specifies how much memory (in kBytes) to use when "
+           "precaching a URL.") );
+
+	setWhatsThis(cache_dvds_spin, tr("Cache for DVDs"), 
+		tr("This option specifies how much memory (in kBytes) to use when "
+           "precaching a DVD.<br><b>Warning:</b> Seeking might not work "
+           "properly (including chapter switching) when using a cache for DVDs.") );
 }
 
 #include "moc_prefperformance.cpp"
