@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "prefwidget.h"
 
 #include "preferences.h"
+#include "config.h"
 
 class PrefPerformance : public PrefWidget, public Ui::PrefPerformance
 {
@@ -44,11 +45,14 @@ public:
 protected:
 	virtual void createHelp();
 
-	void setCacheEnabled(bool b);
-	bool cacheEnabled();
+	void setCacheForFiles(int n);
+	int cacheForFiles();
 
-	void setCache(int n);
-	int cache();
+	void setCacheForStreams(int n);
+	int cacheForStreams();
+
+	void setCacheForDVDs(int n);
+	int cacheForDVDs();
 
 	void setPriority(int n);
 	int priority();
@@ -59,11 +63,8 @@ protected:
 	void setHardFrameDrop(bool b);
 	bool hardFrameDrop();
 
-	void setSkipLoop(bool b);
-	bool skipLoop();
-
-	void setSkipFrames(bool b);
-	bool skipFrames();
+	void setSkipLoop(Preferences::H264LoopFilter value);
+	Preferences::H264LoopFilter skipLoop();
 
 	void setAutoSyncFactor(int factor);
 	int autoSyncFactor();
@@ -71,8 +72,10 @@ protected:
 	void setAutoSyncActivated(bool b);
 	bool autoSyncActivated();
 
+#if !SMART_DVD_CHAPTERS
 	void setFastChapterSeeking(bool b);
 	bool fastChapterSeeking();
+#endif
 
 	void setFastAudioSwitching(Preferences::OptionState value);
 	Preferences::OptionState fastAudioSwitching();
