@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,15 +31,15 @@ PrefSubtitles::PrefSubtitles(QWidget * parent, Qt::WindowFlags f)
 {
 	setupUi(this);
 
-#if !USE_SUBFONT
-	subfont_check->hide();
+	ttf_font_edit->setDialogType(FileChooser::GetFileName);
+#ifdef Q_OS_WIN
+	ttf_font_edit->setOptions(QFileDialog::DontUseNativeDialog);
 #endif
 
 	encodings = new Encodings(this);
 	font_encoding_combo->insertItems( 0, encodings->list() );
 
-	//languageChange();
-	createHelp();
+	retranslateStrings();
 }
 
 PrefSubtitles::~PrefSubtitles()
@@ -73,6 +73,9 @@ void PrefSubtitles::retranslateStrings() {
 
 	sub_pos_label->setNum( sub_pos_slider->value() );
 
+	ttf_font_edit->setCaption(tr("Choose a ttf file"));
+	ttf_font_edit->setFilter(tr("Truetype Fonts") + " (*.ttf)");
+
 	createHelp();
 }
 
@@ -82,6 +85,7 @@ void PrefSubtitles::setData(Preferences * pref) {
 	setUseFontconfig( pref->use_fontconfig );
 	setFontAutoscale( pref->font_autoscale );
 	setFontTextscale( pref->initial_sub_scale );
+	setAssFontScale( pref->initial_sub_scale_ass );
 	setAutoloadSub( pref->autoload_sub );
 	setFontFuzziness( pref->subfuzziness );
 	setFontEncoding( pref->subcp );
@@ -91,10 +95,6 @@ void PrefSubtitles::setData(Preferences * pref) {
 	setAssStyles( pref->ass_styles );
 	setSubPos( pref->initial_sub_pos );
 	setSubtitlesOnScreenshots( pref->subtitles_on_screenshots );
-
-#if USE_SUBFONT
-	setUseSubfont( pref->use_subfont );
-#endif
 }
 
 void PrefSubtitles::getData(Preferences * pref) {
@@ -104,7 +104,8 @@ void PrefSubtitles::getData(Preferences * pref) {
 	TEST_AND_SET(pref->font_file, fontFile());
 	TEST_AND_SET(pref->use_fontconfig, useFontconfig());
 	TEST_AND_SET(pref->font_autoscale, fontAutoscale());
-	TEST_AND_SET(pref->initial_sub_scale, fontTextscale());
+	pref->initial_sub_scale = fontTextscale();
+	pref->initial_sub_scale_ass = assFontScale();
 	TEST_AND_SET(pref->autoload_sub, autoloadSub());
 	TEST_AND_SET(pref->subfuzziness, fontFuzziness());
 	TEST_AND_SET(pref->subcp, fontEncoding());
@@ -114,10 +115,6 @@ void PrefSubtitles::getData(Preferences * pref) {
 	TEST_AND_SET(pref->ass_styles, assStyles());
 	pref->initial_sub_pos = subPos();
 	TEST_AND_SET(pref->subtitles_on_screenshots, subtitlesOnScreenshots());
-
-#if USE_SUBFONT
-	TEST_AND_SET(pref->use_subfont, useSubfont());
-#endif
 }
 
 void PrefSubtitles::setFontName(QString font_name) {
@@ -154,14 +151,22 @@ int PrefSubtitles::fontAutoscale() {
 	return font_autoscale_combo->currentIndex();
 }
 
-void PrefSubtitles::setFontTextscale(int n) {
+void PrefSubtitles::setFontTextscale(double n) {
 	font_text_scale->setValue(n);
 }
 
-int PrefSubtitles::fontTextscale() {
+double PrefSubtitles::fontTextscale() {
 	return font_text_scale->value();
 }
 
+void PrefSubtitles::setAssFontScale(double n) {
+	ass_font_scale->setValue(n);
+}
+
+double PrefSubtitles::assFontScale() {
+	return ass_font_scale->value();
+}
+
 void PrefSubtitles::setAutoloadSub(bool v) {
 	font_autoload_check->setChecked(v);
 }
@@ -205,7 +210,7 @@ bool PrefSubtitles::useFontASS() {
 void PrefSubtitles::setAssColor( unsigned int color ) {
 	ass_color = color;
 #ifdef Q_OS_WIN
-	colorButton->setStyleSheet( "border-width: 1px; border-style: solid; border-color: #000000; background: #" + Helper::colorToRGB(ass_color) + ";");
+	colorButton->setStyleSheet( "border-width: 1px; border-style: solid; border-color: #000000; background: #" + Helper::colorToRRGGBB(ass_color) + ";");
 #else
 	//colorButton->setAutoFillBackground(true);
 	Helper::setBackgroundColor( colorButton, color );
@@ -220,7 +225,7 @@ void PrefSubtitles::setAssBorderColor( unsigned int color ) {
 	ass_border_color = color;
 
 #ifdef Q_OS_WIN
-	borderButton->setStyleSheet( "border-width: 1px; border-style: solid; border-color: #000000; background: #" + Helper::colorToRGB(ass_border_color) + ";");
+	borderButton->setStyleSheet( "border-width: 1px; border-style: solid; border-color: #000000; background: #" + Helper::colorToRRGGBB(ass_border_color) + ";");
 #else
 	//borderButton->setAutoFillBackground(true);
 	Helper::setBackgroundColor( borderButton, color );
@@ -247,16 +252,6 @@ int PrefSubtitles::fontFuzziness() {
 	return font_autoload_combo->currentIndex();
 }
 
-#if USE_SUBFONT
-void PrefSubtitles::setUseSubfont(bool b) {
-	subfont_check->setChecked(b);
-}
-
-bool PrefSubtitles::useSubfont() {
-	return subfont_check->isChecked();
-}
-#endif
-
 void PrefSubtitles::setSubtitlesOnScreenshots(bool b) {
 	subtitles_on_screeshots_check->setChecked(b);
 }
@@ -266,25 +261,6 @@ bool PrefSubtitles::subtitlesOnScreenshots() {
 }
 
 
-void PrefSubtitles::on_searchButton_clicked() {
-	QString s = "";
-
-	QString f;
-
-	s = MyFileDialog::getOpenFileName(
-                        this, tr("Choose a ttf file"), 
-	                    ttf_font_edit->text(),
-    	                tr("Truetype Fonts") + " (*.ttf)"
-#ifdef Q_OS_WIN
-                        , &f, QFileDialog::DontUseNativeDialog
-#endif
-                        );
-
-	if (!s.isEmpty()) {
-		ttf_font_edit->setText(s);
-	}
-}
-
 void PrefSubtitles::on_colorButton_clicked() {
 	QColor c = QColorDialog::getColor ( ass_color, this );
 	if (c.isValid()) {
@@ -302,11 +278,69 @@ void PrefSubtitles::on_borderButton_clicked() {
 void PrefSubtitles::createHelp() {
 	clearHelp();
 
+	addSectionTitle(tr("Subtitles"));
+
+	setWhatsThis(font_autoload_combo, tr("Autoload"), 
+        tr("Select the subtitle autoload method.") );
+
+	setWhatsThis(font_autoload_check, tr("Select first available subtitle"), 
+        tr("If there are one or more subtitle tracks available, one of them "
+           "will be automatically selected, usually the first one, although if "
+           "one of them matches the user's preferred language that one will "
+           "be used instead.") );
+
+	setWhatsThis(font_encoding_combo, tr("Default subtitle encoding"), 
+        tr("Select the encoding which will be used for subtitle files.") );
+
 	setWhatsThis(sub_pos_slider, tr("Subtitle position"),
 		tr("This option specifies the position of the subtitles over the "
            "video window. <i>100</i> means the bottom, while <i>0</i> means "
            "the top." ) );
 
+	setWhatsThis(subtitles_on_screeshots_check, 
+        tr("Include subtitles on screenshots"), 
+        tr("If this option is checked, the subtitles will appear in the "
+           "screenshots. Note: it may cause some troubles sometimes." ) );
+
+	addSectionTitle(tr("Font"));
+
+	setWhatsThis(ttf_font_edit, tr("TTF font"), 
+        tr("Here you can select a ttf font to be used for the subtitles. "
+           "Usually you'll find a lot of ttf fonts in <i>%1</i>.")
+#ifdef Q_OS_WIN
+        .arg("C:\\Windows\\Fonts\\")
+#else
+        .arg("/usr/X11R6/lib/X11/fonts/truetype/")
+#endif
+        );
+
+	setWhatsThis(fontCombo, tr("System font"), 
+        tr("Here you can select a system font to be used for the subtitles "
+           "and OSD. <b>Note:</b> requires a MPlayer with fontconfig support.") );
+
+	setWhatsThis(font_autoscale_combo, tr("Autoscale"), 
+        tr("Select the subtitle autoscaling method.") );
+
+	setWhatsThis(font_text_scale, tr("Default scale for normal subtitles"),
+		tr("This option specifies the default font scale for normal (white) "
+           "subtitles which will be used for new videos."));
+
+	setWhatsThis(ass_font_scale, tr("Default scale for SSA/ASS subtitles"),
+		tr("This option specifies the default font scale for SSA/ASS "
+           "subtitles which will be used for new videos."));
+
+	addSectionTitle(tr("SSA/ASS library"));
+
+	setWhatsThis(font_ass_check, tr("Use SSA/ASS library for subtitle rendering"), 
+        tr("Check this option to activate the SSA/ASS library. It provides "
+           "nicer subtitles, so it's a good idea to do it.") );
+
+	setWhatsThis(colorButton, tr("Text color"), 
+        tr("Select the color for the text of the subtitles.") );
+
+	setWhatsThis(borderButton, tr("Border color"), 
+        tr("Select the color for the border of the subtitles.") );
+
 	setWhatsThis(ass_styles_edit, tr("SSA/ASS styles"), 
 		tr("Here you can override styles for SSA/ASS subtitles. "
            "It can be also used for fine-tuning the rendering of SRT and SUB "
