@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 
 #include "ui_prefsubtitles.h"
 #include "prefwidget.h"
-#include "config.h"
 
 class Preferences;
 class Encodings;
@@ -58,8 +57,11 @@ protected:
 	void setFontAutoscale(int n);
 	int fontAutoscale();
 
-	void setFontTextscale(int n);
-	int fontTextscale();
+	void setFontTextscale(double n);
+	double fontTextscale();
+
+	void setAssFontScale(double n);
+	double assFontScale();
 
 	void setAutoloadSub(bool v);
 	bool autoloadSub();
@@ -88,16 +90,10 @@ protected:
 	void setSubtitlesOnScreenshots(bool b);
 	bool subtitlesOnScreenshots();
 
-#if USE_SUBFONT
-	void setUseSubfont(bool b);
-	bool useSubfont();
-#endif
-
 protected:
 	virtual void retranslateStrings();
 
 protected slots:
-	void on_searchButton_clicked();
 	void on_colorButton_clicked();
 	void on_borderButton_clicked();
 
