@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,6 +37,10 @@ QPixmap PrefWidget::sectionIcon() {
 	return QPixmap();
 }
 
+void PrefWidget::addSectionTitle(const QString & title) {
+	help_message += "<h2>"+title+"</h2>";
+}
+
 void PrefWidget::setWhatsThis( QWidget *w, const QString & title, 
                                const QString & text)
 {
