@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,77 +18,11 @@
 
 #include "timeslider.h"
 
-#if QT_VERSION > 0x040000
-#include <stdlib.h>
-#include <QApplication>
-#include <QStyle>
 #include <QWheelEvent>
-#include <QMouseEvent>
-#include <QApplication>
-#endif
+#include <QTimer>
 
 #define DEBUG 0
 
-MySlider::MySlider( QWidget * parent ) : QSlider(parent)
-{
-	setOrientation( Qt::Horizontal );
-}
-
-MySlider::~MySlider() {
-}
-
-// The code from the following function is from Javier Daz, 
-// taken from a post in the Qt-interest mailing list.
-void MySlider::mousePressEvent( QMouseEvent * e ) {
-#if QT_VERSION < 0x040000
-	if (e->button() == Qt::LeftButton) {
-		if ( !sliderRect().contains(e->pos()) ) {
-			// Pongo como valor el correspondiente al lugar donde hemos hecho click
-			int value = Q3RangeControl::valueFromPosition( e->x(), width() );
-			setValue(value);
-			// Representa un movimiento en el slider
-			emit sliderMoved(value);
-		}
-		else
-			QSlider::mousePressEvent(e);
-	}
-#else
-	// FIXME:
-	// The code doesn't work well with right to left layout,
-	// so it's disabled.
-	if (qApp->isRightToLeft()) {
-		QSlider::mousePressEvent(e);
-		return;
-	}
-
-	int range = maximum()-minimum();
-	int pos = (e->x() * range) / width();
-	//qDebug( "width: %d x: %d", width(), e->x());
-	//qDebug( "range: %d pos: %d value: %d", range, pos, value());
-
-	// Calculate how many positions takes the slider handle
-	int metric = qApp->style()->pixelMetric( QStyle::PM_SliderLength );
-	double one_tick_pixels = (double) width() / range;
-	int slider_handle_positions = metric / one_tick_pixels;
-
-	/*
-	qDebug("metric: %d", metric );
-	qDebug("one_tick_pixels :%f", one_tick_pixels);
-	qDebug("width() :%d", width());
-	qDebug("slider_handle_positions: %d", slider_handle_positions);
-	*/
-
-	if (abs(pos - value()) > slider_handle_positions) { 
-		setValue(pos);
-		emit sliderMoved( pos );
-	} else {
-		QSlider::mousePressEvent(e);
-	}
-#endif
-}
-
-
-
 TimeSlider::TimeSlider( QWidget * parent ) : MySlider(parent)
 {
 	dont_update = FALSE;
@@ -102,6 +36,14 @@ TimeSlider::TimeSlider( QWidget * parent ) : MySlider(parent)
 	connect( this, SIGNAL( sliderReleased() ), this, SLOT( resumeUpdate() ) );
 	connect( this, SIGNAL( sliderReleased() ), this, SLOT( mouseReleased() ) );
 	connect( this, SIGNAL( valueChanged(int) ), this, SLOT( valueChanged_slot(int) ) );
+#if ENABLE_DELAYED_DRAGGING
+	connect( this, SIGNAL(draggingPos(int) ), this, SLOT(checkDragging(int)) );
+	
+	last_pos_to_send = -1;
+	timer = new QTimer(this);
+	connect( timer, SIGNAL(timeout()), this, SLOT(sendDelayedPos()) );
+	timer->start(200);
+#endif
 }
 
 TimeSlider::~TimeSlider() {
@@ -150,6 +92,30 @@ void TimeSlider::valueChanged_slot(int v) {
 	}
 }
 
+#if ENABLE_DELAYED_DRAGGING
+void TimeSlider::setDragDelay(int d) {
+	qDebug("TimeSlider::setDragDelay: %d", d);
+	timer->setInterval(d);
+}
+
+int TimeSlider::dragDelay() {
+	return timer->interval();
+}
+
+void TimeSlider::checkDragging(int v) {
+	qDebug("TimeSlider::checkDragging: %d", v);
+	last_pos_to_send = v;
+}
+
+void TimeSlider::sendDelayedPos() {
+	if (last_pos_to_send != -1) {
+		qDebug("TimeSlider::sendDelayedPos: %d", last_pos_to_send);
+		emit delayedDraggingPos(last_pos_to_send);
+		last_pos_to_send = -1;
+	}
+}
+#endif
+
 void TimeSlider::setPos(int v) {
 	#if DEBUG
 	qDebug("TimeSlider::setPos: %d", v);
