@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,20 +19,8 @@
 #ifndef _TIMESLIDER_H_
 #define _TIMESLIDER_H_
 
-#include <QSlider>
-
-class MySlider : public QSlider
-{
-	Q_OBJECT
-
-public:
-	MySlider( QWidget * parent );
-	~MySlider();
-
-protected:
-	void mousePressEvent ( QMouseEvent * event );
-};
-
+#include "myslider.h"
+#include "config.h"
 
 class TimeSlider : public MySlider 
 {
@@ -45,22 +33,40 @@ public:
 public slots:
 	virtual void setPos(int); // Don't use setValue!
 	virtual int pos();
+#if ENABLE_DELAYED_DRAGGING
+	void setDragDelay(int);
+	int dragDelay();
+#endif
 
 signals:
-	void posChanged(int value);
-	void draggingPos(int value);
+	void posChanged(int);
+	void draggingPos(int);
+#if ENABLE_DELAYED_DRAGGING
+	//! Emitted with a few ms of delay
+	void delayedDraggingPos(int);
+#endif
 
 protected slots:
 	void stopUpdate();
 	void resumeUpdate();
 	void mouseReleased();
 	void valueChanged_slot(int);
+#if ENABLE_DELAYED_DRAGGING
+	void checkDragging(int);
+	void sendDelayedPos();
+#endif
 
 	virtual void wheelEvent( QWheelEvent * e );
 
 private:
 	bool dont_update;
 	int position;
+	
+#if ENABLE_DELAYED_DRAGGING
+	int last_pos_to_send;
+	QTimer * timer;
+#endif
 };
 
 #endif
+
