@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +18,10 @@
 
 #include "widgetactions.h"
 
+#if MINI_ARROW_BUTTONS
+#include <QToolButton>
+#endif
+
 MyWidgetAction::MyWidgetAction( QWidget * parent )
 	: QWidgetAction(parent)
 {
@@ -47,6 +51,9 @@ void MyWidgetAction::propagate_enabled(bool b) {
 TimeSliderAction::TimeSliderAction( QWidget * parent )
 	: MyWidgetAction(parent)
 {
+#if ENABLE_DELAYED_DRAGGING
+	drag_delay = 200;
+#endif
 }
 
 TimeSliderAction::~TimeSliderAction() {
@@ -70,6 +77,22 @@ int TimeSliderAction::pos() {
 	}
 }
 
+#if ENABLE_DELAYED_DRAGGING
+void TimeSliderAction::setDragDelay(int d) {
+	drag_delay = d;
+
+	QList<QWidget *> l = createdWidgets();
+	for (int n=0; n < l.count(); n++) {
+		TimeSlider *s = (TimeSlider*) l[n];
+		s->setDragDelay(drag_delay);
+	}
+}
+
+int TimeSliderAction::dragDelay() {
+	return drag_delay;
+}
+#endif
+
 QWidget * TimeSliderAction::createWidget ( QWidget * parent ) {
 	TimeSlider *t = new TimeSlider(parent);
 	t->setEnabled( isEnabled() );
@@ -78,6 +101,12 @@ QWidget * TimeSliderAction::createWidget ( QWidget * parent ) {
              this, SIGNAL(posChanged(int)) );
 	connect( t,    SIGNAL(draggingPos(int)),
              this, SIGNAL(draggingPos(int)) );
+#if ENABLE_DELAYED_DRAGGING
+	t->setDragDelay(drag_delay);
+
+	connect( t,    SIGNAL(delayedDraggingPos(int)),
+	         this, SIGNAL(delayedDraggingPos(int)) );
+#endif
 
 	return t;
 }
@@ -129,4 +158,29 @@ QWidget * VolumeSliderAction::createWidget ( QWidget * parent ) {
 	return t;
 }
 
+#if MINI_ARROW_BUTTONS
+SeekingButton::SeekingButton( QList<QAction*> actions, QWidget * parent ) 
+	: QWidgetAction(parent)
+{
+	_actions = actions;
+}
+
+SeekingButton::~SeekingButton() {
+}
+
+QWidget * SeekingButton::createWidget( QWidget * parent ) {
+	QToolButton * button = new QToolButton(parent);
+	button->setPopupMode(QToolButton::DelayedPopup);
+
+	if (_actions.count() > 0 ) {
+		button->setDefaultAction( _actions[0] );
+	}
+	for (int n = 1; n < _actions.count(); n++) {
+		button->addAction( _actions[n] );
+	}
+
+	return button;
+}
+#endif
+
 #include "moc_widgetactions.cpp"
