@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 
 #include <QWidgetAction>
 #include "timeslider.h"
+#include "config.h"
+#include "guiconfig.h"
 
 class MyWidgetAction : public QWidgetAction
 {
@@ -49,10 +51,20 @@ public:
 public slots:
 	virtual void setPos(int);
 	virtual int pos();
+#if ENABLE_DELAYED_DRAGGING
+	void setDragDelay(int);
+	int dragDelay();
+
+private:
+	int drag_delay;
+#endif
 
 signals:
 	void posChanged(int value);
 	void draggingPos(int value);
+#if ENABLE_DELAYED_DRAGGING
+	void delayedDraggingPos(int);
+#endif
 
 protected:
 	virtual QWidget * createWidget ( QWidget * parent );
@@ -78,5 +90,22 @@ protected:
 	virtual QWidget * createWidget ( QWidget * parent );
 };
 
+
+#if MINI_ARROW_BUTTONS
+class SeekingButton : public QWidgetAction
+{
+	Q_OBJECT
+
+public:
+	SeekingButton( QList<QAction*> actions, QWidget * parent );
+	~SeekingButton();
+
+protected:
+	virtual QWidget * createWidget ( QWidget * parent );
+
+	QList<QAction*> _actions;
+};
+#endif
+
 #endif
 
